@@ -1,5 +1,95 @@
 var NAVTREEINDEX37 =
 {
+"group__DRV__MCSPI__LLD__MODULE.html#ga0d079469a9c669bee03475ec4046f664":[19,7,29,129],
+"group__DRV__MCSPI__LLD__MODULE.html#ga0f21e52de7fd31eb6fdcf2e8e4ecd76f":[19,7,29,85],
+"group__DRV__MCSPI__LLD__MODULE.html#ga10b4f7a1cd024c5173f90d29a01c979d":[19,7,29,99],
+"group__DRV__MCSPI__LLD__MODULE.html#ga140936915c925cbf2348073ac7e67519":[19,7,29,70],
+"group__DRV__MCSPI__LLD__MODULE.html#ga1447ffe86b17d95258dcad6594a3f0a9":[19,7,29,35],
+"group__DRV__MCSPI__LLD__MODULE.html#ga15e08ffa29ce4f9f979e78bdb2e7134e":[19,7,29,125],
+"group__DRV__MCSPI__LLD__MODULE.html#ga18a0f0705c041e22f8abcdf77cd6e3dd":[19,7,29,9],
+"group__DRV__MCSPI__LLD__MODULE.html#ga1b8f03a6e51528ead614029fe659de07":[19,7,29,61],
+"group__DRV__MCSPI__LLD__MODULE.html#ga1d82310c73b406ad1117ed7ab3950167":[19,7,29,64],
+"group__DRV__MCSPI__LLD__MODULE.html#ga1f7d6df57b9b4131da279698202b612a":[19,7,29,123],
+"group__DRV__MCSPI__LLD__MODULE.html#ga25ffd0409bab65b9abc25c0bf5de5d73":[19,7,29,124],
+"group__DRV__MCSPI__LLD__MODULE.html#ga27af238014f7f4b5ed22d825a0674388":[19,7,29,101],
+"group__DRV__MCSPI__LLD__MODULE.html#ga2a4c303d8853cca2d2bdf6d85f3b7c2a":[19,7,29,127],
+"group__DRV__MCSPI__LLD__MODULE.html#ga30725ee81f017468b53263e635684484":[19,7,29,75],
+"group__DRV__MCSPI__LLD__MODULE.html#ga3288101269c2b0b0fd65f16c9ecfd0f7":[19,7,29,111],
+"group__DRV__MCSPI__LLD__MODULE.html#ga3398429686392c9c2d0dfe06f7dcc7d4":[19,7,29,45],
+"group__DRV__MCSPI__LLD__MODULE.html#ga3433c9f04be494873cb7aa9473004d60":[19,7,29,11],
+"group__DRV__MCSPI__LLD__MODULE.html#ga3444b0f64dd9e0692bfc516dfef58bc8":[19,7,29,13],
+"group__DRV__MCSPI__LLD__MODULE.html#ga363bec181be24770ad7e03f4924f7cf4":[19,7,29,109],
+"group__DRV__MCSPI__LLD__MODULE.html#ga36b49491caee5f27c5f3f0601fa860be":[19,7,29,121],
+"group__DRV__MCSPI__LLD__MODULE.html#ga3819dfc2e142f7608bc1f66208306766":[19,7,29,107],
+"group__DRV__MCSPI__LLD__MODULE.html#ga399cd4ef12d0400125d2615eabd6b561":[19,7,29,52],
+"group__DRV__MCSPI__LLD__MODULE.html#ga3c2e983f3d98da3ecb3e342ee737ef1c":[19,7,29,77],
+"group__DRV__MCSPI__LLD__MODULE.html#ga3c65e70702215e16f839a7bd05815146":[19,7,29,91],
+"group__DRV__MCSPI__LLD__MODULE.html#ga3d4bd7677126fc532635faa9a5a841ca":[19,7,29,46],
+"group__DRV__MCSPI__LLD__MODULE.html#ga3dda2e27f59455e8f026a9e879fd2530":[19,7,29,98],
+"group__DRV__MCSPI__LLD__MODULE.html#ga3f52f1cda834a92e65271acf7156d67d":[19,7,29,21],
+"group__DRV__MCSPI__LLD__MODULE.html#ga3f6a6b50cf7467ed24a47b2901fdd2f6":[19,7,29,89],
+"group__DRV__MCSPI__LLD__MODULE.html#ga4046b1c0d01e5e31855e43c81f02f17d":[19,7,29,68],
+"group__DRV__MCSPI__LLD__MODULE.html#ga42cb25b77155f07fe058c6d81d1a1e32":[19,7,29,60],
+"group__DRV__MCSPI__LLD__MODULE.html#ga439e8f03edc99644be40a5dfbb1b27a9":[19,7,29,36],
+"group__DRV__MCSPI__LLD__MODULE.html#ga451aba2b1ca0c8ccb3547f7598129a3f":[19,7,29,96],
+"group__DRV__MCSPI__LLD__MODULE.html#ga4546259852b6b9b3811a15f0e6f47f52":[19,7,29,84],
+"group__DRV__MCSPI__LLD__MODULE.html#ga454f40200e04c92eedcbae380a6f71f5":[19,7,29,29],
+"group__DRV__MCSPI__LLD__MODULE.html#ga467ce5fb0a6586d7da5dcb3e099e2f12":[19,7,29,67],
+"group__DRV__MCSPI__LLD__MODULE.html#ga471023734e5329ebc65a53092d70730e":[19,7,29,23],
+"group__DRV__MCSPI__LLD__MODULE.html#ga47d5d6f22de36bf91e167f83fa1b6a0f":[19,7,29,55],
+"group__DRV__MCSPI__LLD__MODULE.html#ga4dfee07f911b5fe9c459309906e50ee9":[19,7,29,112],
+"group__DRV__MCSPI__LLD__MODULE.html#ga52d86840ed53916cace8f58ec2631499":[19,7,29,17],
+"group__DRV__MCSPI__LLD__MODULE.html#ga5321095795591db87f4cfeb788abf786":[19,7,29,12],
+"group__DRV__MCSPI__LLD__MODULE.html#ga532219eca14e3d2d768d76df7db46d94":[19,7,29,131],
+"group__DRV__MCSPI__LLD__MODULE.html#ga5778f499f3a83e6cd19bb125946c02d8":[19,7,29,102],
+"group__DRV__MCSPI__LLD__MODULE.html#ga58171f2538a4ae64b076cbb7aa590b6b":[19,7,29,115],
+"group__DRV__MCSPI__LLD__MODULE.html#ga5a3d284fb16accadcc5bf4ff0be3afc7":[19,7,29,51],
+"group__DRV__MCSPI__LLD__MODULE.html#ga5f4e62b9a5145858280b8a6b78d65dad":[19,7,29,42],
+"group__DRV__MCSPI__LLD__MODULE.html#ga646ae244aa2508c975199fb30b8bd211":[19,7,29,31],
+"group__DRV__MCSPI__LLD__MODULE.html#ga6794018a599afa7637bc113c44b91ee0":[19,7,29,25],
+"group__DRV__MCSPI__LLD__MODULE.html#ga67a726475e759359dad263391b261a67":[19,7,29,103],
+"group__DRV__MCSPI__LLD__MODULE.html#ga6929c804ed9ea156addba7f0313add4e":[19,7,29,90],
+"group__DRV__MCSPI__LLD__MODULE.html#ga69f7a16bf39d0ed47de1970b599a7f0c":[19,7,29,34],
+"group__DRV__MCSPI__LLD__MODULE.html#ga6acd9f7a8baa6f88ec8f9df41d4ac0ba":[19,7,29,32],
+"group__DRV__MCSPI__LLD__MODULE.html#ga6e279a2b49068f39ccaaf440fd2c67c9":[19,7,29,49],
+"group__DRV__MCSPI__LLD__MODULE.html#ga6ee3d15c00cc8010788274008357b086":[19,7,29,14],
+"group__DRV__MCSPI__LLD__MODULE.html#ga71171d44985e8ff7dcd5bfe5f3eec430":[19,7,29,88],
+"group__DRV__MCSPI__LLD__MODULE.html#ga72f6d89799df8575c23600628ba9ddfa":[19,7,29,120],
+"group__DRV__MCSPI__LLD__MODULE.html#ga74887f9a92ea908748e13bb18c155f94":[19,7,29,27],
+"group__DRV__MCSPI__LLD__MODULE.html#ga7b39c11444c20b39afc53299c32df1dd":[19,7,29,82],
+"group__DRV__MCSPI__LLD__MODULE.html#ga7d1fbe4e33059cd72c6ec199abe11316":[19,7,29,65],
+"group__DRV__MCSPI__LLD__MODULE.html#ga8071ea166bd58665fd9e9b72bcfdecda":[19,7,29,122],
+"group__DRV__MCSPI__LLD__MODULE.html#ga83bf183e3c28c7641caf951431f89625":[19,7,29,33],
+"group__DRV__MCSPI__LLD__MODULE.html#ga86cc7d555007774d4d431e913fa6c3f6":[19,7,29,113],
+"group__DRV__MCSPI__LLD__MODULE.html#ga88c80bbad2d6a7c56afe2831076d6291":[19,7,29,104],
+"group__DRV__MCSPI__LLD__MODULE.html#ga8a046afdfa57364cf85f221416a4d424":[19,7,29,93],
+"group__DRV__MCSPI__LLD__MODULE.html#ga8ab60e51e1dadfe520dec5115c2f5d1a":[19,7,29,44],
+"group__DRV__MCSPI__LLD__MODULE.html#ga8e6a2cfe47ec2daa916af02cae229ab3":[19,7,29,57],
+"group__DRV__MCSPI__LLD__MODULE.html#ga8ee6f5b71917cfb8fdc05cd48620c2e4":[19,7,29,37],
+"group__DRV__MCSPI__LLD__MODULE.html#ga8f5eb88f42ddea3d0482306ef11bf2b5":[19,7,29,50],
+"group__DRV__MCSPI__LLD__MODULE.html#ga9434813587ba1a7dcfb9a0a8b66623f9":[19,7,29,47],
+"group__DRV__MCSPI__LLD__MODULE.html#ga97cf1b26053f89e1d2db63dc8f96d2d2":[19,7,29,79],
+"group__DRV__MCSPI__LLD__MODULE.html#ga9883ae83b53b8cff51454521a8f5f978":[19,7,29,118],
+"group__DRV__MCSPI__LLD__MODULE.html#ga9ed7923dca9f0152ec7320fcf269a655":[19,7,29,18],
+"group__DRV__MCSPI__LLD__MODULE.html#ga9fd98823e4550df9f74470e49ed96372":[19,7,29,92],
+"group__DRV__MCSPI__LLD__MODULE.html#gaa0e6d15b21841fcb2970e16a9843d87a":[19,7,29,62],
+"group__DRV__MCSPI__LLD__MODULE.html#gaa30204efe0c0512c7ab51e7efc1b0e1d":[19,7,29,78],
+"group__DRV__MCSPI__LLD__MODULE.html#gaa3663721672a8673989b7104ea826713":[19,7,29,59],
+"group__DRV__MCSPI__LLD__MODULE.html#gaae2d0e9af00185a61a45e225c733270c":[19,7,29,106],
+"group__DRV__MCSPI__LLD__MODULE.html#gaae53dbc6ef93d5d1bb5bd20bd7117e95":[19,7,29,105],
+"group__DRV__MCSPI__LLD__MODULE.html#gab3e0972265038d40e593247560f0130d":[19,7,29,100],
+"group__DRV__MCSPI__LLD__MODULE.html#gab495c02282f26f698cac3f280dfc7da3":[19,7,29,76],
+"group__DRV__MCSPI__LLD__MODULE.html#gab5867f6fc63e4da0e32820f372ecb875":[19,7,29,19],
+"group__DRV__MCSPI__LLD__MODULE.html#gab5f4e5c4a64dd77b05ecb2634d7e7758":[19,7,29,22],
+"group__DRV__MCSPI__LLD__MODULE.html#gab676c94c75928feb98ad6bd419d6c6ea":[19,7,29,10],
+"group__DRV__MCSPI__LLD__MODULE.html#gab8ae9bda705fca969feae66d33f4962f":[19,7,29,26],
+"group__DRV__MCSPI__LLD__MODULE.html#gab8d5c4edc0f02d25a1b3c23bb231b412":[19,7,29,20],
+"group__DRV__MCSPI__LLD__MODULE.html#gabaa888ef531c9dda317b001044627a41":[19,7,29,15],
+"group__DRV__MCSPI__LLD__MODULE.html#gabc11d5f12cff17e21e70dbe700dbedb0":[19,7,29,80],
+"group__DRV__MCSPI__LLD__MODULE.html#gabcdb83a136b23476b0ed63389abd91a3":[19,7,29,66],
+"group__DRV__MCSPI__LLD__MODULE.html#gabe697e26455aa50ea6dc87b6dfad3829":[19,7,29,16],
+"group__DRV__MCSPI__LLD__MODULE.html#gabfecd1b6519b00bd0a6fff7e88bdf6aa":[19,7,29,94],
+"group__DRV__MCSPI__LLD__MODULE.html#gac00e3b7be4c4918a7acf16c07577aac8":[19,7,29,40],
 "group__DRV__MCSPI__LLD__MODULE.html#gac1d453aab852bc1c27bf6183a8914e59":[19,7,29,58],
 "group__DRV__MCSPI__LLD__MODULE.html#gac41bb9a19845e7c2770b7348e1394617":[19,7,29,73],
 "group__DRV__MCSPI__LLD__MODULE.html#gac58ac95f977011e5b9cbb3edeec28740":[19,7,29,56],
@@ -148,106 +238,16 @@ var NAVTREEINDEX37 =
 "group__DRV__MPU__FIREWALL__MODULE.html#gaa8ff31c593309a90a9fcfa4cf9459431":[19,7,33,8],
 "group__DRV__MPU__FIREWALL__MODULE.html#gga61ea5ccfc887af5214b095cef7811ff7a67f40791064a819ac15a1804995f2592":[19,7,33,4,1],
 "group__DRV__MPU__FIREWALL__MODULE.html#gga61ea5ccfc887af5214b095cef7811ff7aef50d6cde1d60860c2f27bcaa4b6322a":[19,7,33,4,0],
-"group__DRV__OSPI__LLD__CALLBACK__API__MODULE.html":[19,7,35,3],
-"group__DRV__OSPI__LLD__CALLBACK__API__MODULE.html#ga03b7d6c2985ac9fd8c45197b5223aa3e":[19,7,35,3,0],
-"group__DRV__OSPI__LLD__CALLBACK__API__MODULE.html#ga4c230a549a3fd2c44d50476c3b57b8a9":[19,7,35,3,1],
+"group__DRV__OSPI__LLD__CALLBACK__API__MODULE.html":[19,7,35,2],
+"group__DRV__OSPI__LLD__CALLBACK__API__MODULE.html#ga03b7d6c2985ac9fd8c45197b5223aa3e":[19,7,35,2,0],
+"group__DRV__OSPI__LLD__CALLBACK__API__MODULE.html#ga4c230a549a3fd2c44d50476c3b57b8a9":[19,7,35,2,1],
 "group__DRV__OSPI__LLD__MODULE.html":[19,7,35],
-"group__DRV__OSPI__LLD__MODULE.html#ga06537aa23596702c0565fa7d18d0d1e3":[19,7,35,27],
-"group__DRV__OSPI__LLD__MODULE.html#ga23709aa421bf0c8b7b2f68cf0589f6d6":[19,7,35,28],
-"group__DRV__OSPI__LLD__MODULE.html#ga3ab5248fdb48c86cdc6dafa3cef9653c":[19,7,35,31],
-"group__DRV__OSPI__LLD__MODULE.html#ga41969ba56f8290fa5257258a3a256f67":[19,7,35,21],
-"group__DRV__OSPI__LLD__MODULE.html#ga469aaad2717d1a24ec36c3a15a7eae5f":[19,7,35,38],
-"group__DRV__OSPI__LLD__MODULE.html#ga472c6647443cd1da5f0444140509d5f3":[19,7,35,40],
-"group__DRV__OSPI__LLD__MODULE.html#ga4f4643768578595aae226c70a0d2f076":[19,7,35,48],
-"group__DRV__OSPI__LLD__MODULE.html#ga50d149b2fccd6e812bb0dd6f59a7b94d":[19,7,35,44],
-"group__DRV__OSPI__LLD__MODULE.html#ga57583095a9c4d74c7d6e6b7735e2c444":[19,7,35,50],
-"group__DRV__OSPI__LLD__MODULE.html#ga5d534d3e63f8d981404d8341c6d6d053":[19,7,35,37],
-"group__DRV__OSPI__LLD__MODULE.html#ga61928eb243bab120533b9f9a0395dd7b":[19,7,35,26],
-"group__DRV__OSPI__LLD__MODULE.html#ga648138c29d9a9eac6698a2b4e3aa9ede":[19,7,35,43],
-"group__DRV__OSPI__LLD__MODULE.html#ga6a1174de17525d6b8ff650a207fe0863":[19,7,35,49],
-"group__DRV__OSPI__LLD__MODULE.html#ga77f4efa40a226851874098641825ae36":[19,7,35,46],
-"group__DRV__OSPI__LLD__MODULE.html#ga79a83a57a9d53e16d427da7085484340":[19,7,35,45],
-"group__DRV__OSPI__LLD__MODULE.html#ga79d77e39f6bd7e3760400dbd9c9517a0":[19,7,35,42],
-"group__DRV__OSPI__LLD__MODULE.html#ga7c33406bc45d1604343695af8a3226ab":[19,7,35,16],
-"group__DRV__OSPI__LLD__MODULE.html#ga7d44d2a33a98f0eca8e9eb8dd81a9056":[19,7,35,32],
-"group__DRV__OSPI__LLD__MODULE.html#ga7d6bd3a34c82f66d9c1cb10480793aaa":[19,7,35,11],
-"group__DRV__OSPI__LLD__MODULE.html#ga7dc3c40915b842f332dbff0b4d6e4489":[19,7,35,55],
-"group__DRV__OSPI__LLD__MODULE.html#ga7dcfaf7de3dd1d3981b73fd25ddfcc97":[19,7,35,30],
-"group__DRV__OSPI__LLD__MODULE.html#ga7ee32dfb14b16db0f8c2d6cdf140c743":[19,7,35,34],
-"group__DRV__OSPI__LLD__MODULE.html#ga8482f3d9ad125c31a3580e5dd0f88b7b":[19,7,35,9],
-"group__DRV__OSPI__LLD__MODULE.html#ga864d26872cd84abdb4ff93e5657c93b6":[19,7,35,54],
-"group__DRV__OSPI__LLD__MODULE.html#ga8bd7139781e775813b256f0cb7a0a007":[19,7,35,19],
-"group__DRV__OSPI__LLD__MODULE.html#ga902f5f5c77a6ba34195d8f2fb2111084":[19,7,35,39],
-"group__DRV__OSPI__LLD__MODULE.html#ga914c31e0aa9d3128653c66fb649b9a72":[19,7,35,18],
-"group__DRV__OSPI__LLD__MODULE.html#ga91f0d750162c0ef0529fc3c4657ee3a3":[19,7,35,14],
-"group__DRV__OSPI__LLD__MODULE.html#ga928e0281d6364ec0942501d530e6de75":[19,7,35,25],
-"group__DRV__OSPI__LLD__MODULE.html#ga948ce22a66ab874258bed621c990df72":[19,7,35,8],
-"group__DRV__OSPI__LLD__MODULE.html#ga9f104789738763e778992459be823072":[19,7,35,51],
-"group__DRV__OSPI__LLD__MODULE.html#gaa8bac9ef393d38a227ade00fdac952a5":[19,7,35,22],
-"group__DRV__OSPI__LLD__MODULE.html#gaab37281f1de2120a6e8c1bb396be8b85":[19,7,35,47],
-"group__DRV__OSPI__LLD__MODULE.html#gaacd9c2a641ff3c014a39fc94980bd3cd":[19,7,35,35],
-"group__DRV__OSPI__LLD__MODULE.html#gaaef3b5598e9c6578bb727f76e4633b46":[19,7,35,23],
-"group__DRV__OSPI__LLD__MODULE.html#gab72a37197e96fc7690b1dfdb751e1cca":[19,7,35,20],
-"group__DRV__OSPI__LLD__MODULE.html#gabf886a11af66b463ed93bf674140e149":[19,7,35,13],
-"group__DRV__OSPI__LLD__MODULE.html#gabfc137bf2576fc0426a59f5d718a9a72":[19,7,35,24],
-"group__DRV__OSPI__LLD__MODULE.html#gac019dac1e7917fd6351ac4840e763195":[19,7,35,10],
-"group__DRV__OSPI__LLD__MODULE.html#gac17f5f295276bb71eb228f998f096db9":[19,7,35,53],
-"group__DRV__OSPI__LLD__MODULE.html#gad33321c4d3c0e127cc9dbc5150a5d946":[19,7,35,17],
-"group__DRV__OSPI__LLD__MODULE.html#gadfd42de3f9f3f1aaa42329ab54226f15":[19,7,35,41],
-"group__DRV__OSPI__LLD__MODULE.html#gae2fc4e0801ce850ed23824675d8573ad":[19,7,35,29],
-"group__DRV__OSPI__LLD__MODULE.html#gae589b4ecf0e83feaf138aa818f87a439":[19,7,35,52],
-"group__DRV__OSPI__LLD__MODULE.html#gae61b7b91fdcb31ffd5b0ce67a1d80355":[19,7,35,36],
-"group__DRV__OSPI__LLD__MODULE.html#gae9b31d26f1bb582b75802caf013529ed":[19,7,35,33],
-"group__DRV__OSPI__LLD__MODULE.html#gaf383c0431b9a1e5a4548e496e34a07b0":[19,7,35,12],
-"group__DRV__OSPI__LLD__MODULE.html#gafe5b7c84a86e56c3ad7f73f5e7153a52":[19,7,35,15],
-"group__DRV__OSPI__LLD__PHY__API__MODULE.html":[19,7,35,2],
-"group__DRV__OSPI__LLD__PHY__API__MODULE.html#ga1996b227ac5ed1f5397a28afe81d6905":[19,7,35,2,4],
-"group__DRV__OSPI__LLD__PHY__API__MODULE.html#ga4739dd517f0c7b2dc1e73e3b6b7e6a6e":[19,7,35,2,8],
-"group__DRV__OSPI__LLD__PHY__API__MODULE.html#ga5398c350a84c1755d82ea0d18eab3b6c":[19,7,35,2,0],
-"group__DRV__OSPI__LLD__PHY__API__MODULE.html#ga9884faa778c08b0b3bd5ed03e2eea4da":[19,7,35,2,5],
-"group__DRV__OSPI__LLD__PHY__API__MODULE.html#ga9bb7ea9af3db5dba60bee72847dc51bd":[19,7,35,2,3],
-"group__DRV__OSPI__LLD__PHY__API__MODULE.html#gaa172ebcf9aab076b2a762df685e4756a":[19,7,35,2,1],
-"group__DRV__OSPI__LLD__PHY__API__MODULE.html#gacb3194b5e135b0f38675397377970798":[19,7,35,2,7],
-"group__DRV__OSPI__LLD__PHY__API__MODULE.html#gae65321a31df29f62c8aa6facbe9610e9":[19,7,35,2,6],
-"group__DRV__OSPI__LLD__PHY__API__MODULE.html#gafd227d515282233156c11c820eecf274":[19,7,35,2,2],
-"group__DRV__OSPI__LLD__READ__WRITE__MODULE.html":[19,7,35,4],
-"group__DRV__OSPI__LLD__READ__WRITE__MODULE.html#ga44904dad5400f05b8aa05b370d8cff73":[19,7,35,4,2],
-"group__DRV__OSPI__LLD__READ__WRITE__MODULE.html#ga5c6aa78b2b05cca8bd7a184a1b040f87":[19,7,35,4,3],
-"group__DRV__OSPI__LLD__READ__WRITE__MODULE.html#ga6407e10535774e092dd39d2c7c5f8743":[19,7,35,4,6],
-"group__DRV__OSPI__LLD__READ__WRITE__MODULE.html#ga974e36996b60c99ea033e9e854c12d58":[19,7,35,4,1],
-"group__DRV__OSPI__LLD__READ__WRITE__MODULE.html#gaa6446e3c2faf32c5b7ba35107a53d6a8":[19,7,35,4,0],
-"group__DRV__OSPI__LLD__READ__WRITE__MODULE.html#gae04505fe510467c64703d67b1913b160":[19,7,35,4,5],
-"group__DRV__OSPI__LLD__READ__WRITE__MODULE.html#gafccf7cee32027d511f06e5910e94780c":[19,7,35,4,4],
-"group__DRV__OSPI__LLD__TRANS__INIT__API__MODULE.html":[19,7,35,5],
-"group__DRV__OSPI__LLD__TRANS__INIT__API__MODULE.html#ga0fe11a08bf60be67834bef6e01e849bf":[19,7,35,5,0],
-"group__DRV__OSPI__LLD__TRANS__INIT__API__MODULE.html#ga9ab0c1b20af7cffce766e32023d61edc":[19,7,35,5,1],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html":[19,7,35,6],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga0158b2bd97a60a214810235bc5aac5d3":[19,7,35,6,19],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga02edc39c6b33b5737db42e60bcceca99":[19,7,35,6,26],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga0f0bfdfb774a99bd9026c83660294573":[19,7,35,6,11],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga1b17ac446d98abbd63543bf886ce624f":[19,7,35,6,2],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga293ab76c49ae513770ec99aaf2628de8":[19,7,35,6,13],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga38049e4f78b80117ea928a12ff132079":[19,7,35,6,16],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga4d9e5aff7ad6456e0d815186a7919dc8":[19,7,35,6,6],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga524ac252821b7724dad54a843145a2e7":[19,7,35,6,18],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga5a0958a50a09a9e62582b0035c0f79aa":[19,7,35,6,5],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga5ccf5b1bb52fbb611a66ad3f6f98d369":[19,7,35,6,27],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga6c07ae3c3a51c03c69f62c4b445151fb":[19,7,35,6,17],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga6dc045ceaa1c21b0321535845d490aeb":[19,7,35,6,9],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga6e69e880718ec9dc623e9a170cb5a795":[19,7,35,6,20],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga74f2254ae86a25971f70d831f148d0a9":[19,7,35,6,3],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga75d7dd248bff5f55d723eef16ae7e67a":[19,7,35,6,14],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga79a7b0b4d3d741ccc0e23d9a494eaae7":[19,7,35,6,25],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga7fd5f570e087094f6ac78513064767bd":[19,7,35,6,1],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga813275e44d946c309b6f19bb926d9ef5":[19,7,35,6,0],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga879c2dbf35ef2a9d029cccbd14a33093":[19,7,35,6,21],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga8e2241ab0c3a07b9f39e61e0a971d94f":[19,7,35,6,7],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#ga8f7869fb6bd7f820edef9fcc15842766":[19,7,35,6,4],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#gab206fa62461cab17c7223b3bf05bd5ae":[19,7,35,6,8],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#gab4b14ee821c3f8a347ee13c830b0f036":[19,7,35,6,24],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#gaccebd769dc5af3e2e2a8016882f3cb20":[19,7,35,6,23],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#gae0f46f5a324e40886f6b0f192974b06c":[19,7,35,6,12],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#gae878f0f8b6d5a0920bf1b51f75e09a29":[19,7,35,6,22],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#gaf10f49b359bd616d204338e0f82f532a":[19,7,35,6,10],
-"group__DRV__OSPI__LLD__USER__INTERFACE__API__MODULE.html#gaffd5231cff653145df50c49b228478d5":[19,7,35,6,15]
+"group__DRV__OSPI__LLD__MODULE.html#ga06537aa23596702c0565fa7d18d0d1e3":[19,7,35,26],
+"group__DRV__OSPI__LLD__MODULE.html#ga23709aa421bf0c8b7b2f68cf0589f6d6":[19,7,35,27],
+"group__DRV__OSPI__LLD__MODULE.html#ga3ab5248fdb48c86cdc6dafa3cef9653c":[19,7,35,30],
+"group__DRV__OSPI__LLD__MODULE.html#ga41969ba56f8290fa5257258a3a256f67":[19,7,35,20],
+"group__DRV__OSPI__LLD__MODULE.html#ga469aaad2717d1a24ec36c3a15a7eae5f":[19,7,35,37],
+"group__DRV__OSPI__LLD__MODULE.html#ga472c6647443cd1da5f0444140509d5f3":[19,7,35,39],
+"group__DRV__OSPI__LLD__MODULE.html#ga4f4643768578595aae226c70a0d2f076":[19,7,35,47],
+"group__DRV__OSPI__LLD__MODULE.html#ga50d149b2fccd6e812bb0dd6f59a7b94d":[19,7,35,43]
 };
