@@ -1,5 +1,108 @@
 var NAVTREEINDEX54 =
 {
+"group__timer.html#ga7e3e5c8b972b0324b077b3772fb4b22c":[19,12,6,6],
+"group__timer.html#gaabc1fbd82ba55d3392bd2bf00e2ee4b4":[19,12,6,3],
+"group__timer.html#gadeb4934af856a779b604dadda61a35aa":[19,12,6,8],
+"group__timer.html#gafb4ddbfe676f1235b47994ce18951199":[19,12,6,10],
+"group__timer.html#gga0a4ba5c04c09fd739d06e31b447c2ce3a788aabc9cb13df9f358d0de0201821aa":[19,12,6,5,0],
+"group__timer.html#gga0a4ba5c04c09fd739d06e31b447c2ce3a85a011c4aa157d832729103aa6429be4":[19,12,6,5,1],
+"group__timer.html#gga0a4ba5c04c09fd739d06e31b447c2ce3adffa1f2d764d43c26eccc96a89aeab11":[19,12,6,5,2],
+"group__trb__api__grp.html":[19,7,47,0,6],
+"group__trb__api__grp.html#ga1bb7c6f3ac26152ab30944f71d9cb6e2":[19,7,47,0,6,0],
+"group__trb__api__grp.html#gad1c3d36ae244268843f8f71e73e4824b":[19,7,47,0,6,1],
+"group__trb__api__grp.html#gad761bd466131c0d88e289f8e67f6f10e":[19,7,47,0,6,2],
+"group__unibase.html":[19,10,5],
+"group__unibase.html#ga1229a046c08175fcb1d897766e55e882":[19,10,5,22],
+"group__unibase.html#ga184f2b8209363245eaf32baec325ec3b":[19,10,5,11],
+"group__unibase.html#ga1fb85526607326517986bdd59e83e3d4":[19,10,5,23],
+"group__unibase.html#ga3dec6a0c36dbfba7d48e5ffa0538ed82":[19,10,5,18],
+"group__unibase.html#ga4d2f25f8e27608cea69ce00044da4eda":[19,10,5,9],
+"group__unibase.html#ga513c9959a287cf1c059cc5da9eddb806":[19,10,5,6],
+"group__unibase.html#ga514cfd1f68bf813d633cca99dd6fc3ca":[19,10,5,8],
+"group__unibase.html#ga68f23cf256e24c08030ff17a855f0203":[19,10,5,24],
+"group__unibase.html#ga6c6d59d3185dbf846e3ad3b1f89d2e49":[19,10,5,5],
+"group__unibase.html#ga6c91b852ebfbb8e4d7eb09fa022c185e":[19,10,5,19],
+"group__unibase.html#ga6fb83f5e91e704391ff796553d5e0f46":[19,10,5,3],
+"group__unibase.html#ga70ca762232195f8067e933568177ce70":[19,10,5,12],
+"group__unibase.html#ga91294f2720b594ea126f2bfc26240f37":[19,10,5,13],
+"group__unibase.html#ga9d794ed84fac373965c83c9b85e1ab2f":[19,10,5,16],
+"group__unibase.html#gaa72e174000765f6ced7b6c5b1c2fd808":[19,10,5,7],
+"group__unibase.html#gab727909b9b653a4e5fa6537ab9defba0":[19,10,5,14],
+"group__unibase.html#gacd346562ecf9a6cf4abb5c5832612ef2":[19,10,5,10],
+"group__unibase.html#gad79fcdacbcba1e51629236584a39d4ba":[19,10,5,17],
+"group__unibase.html#gade0bd3e2a075c12d3820606af6750f61":[19,10,5,15],
+"group__unibase.html#gae23419e4bbd26ed4cd0dc3d5d9d0e5ef":[19,10,5,4],
+"group__unibase.html#gaee5b1ceb739c1df6b35b94809080834b":[19,10,5,21],
+"group__unibase.html#gaee6247f0bbaf74712e84f3a2c10318a9":[19,10,5,20],
+"group__unibase.html#gga91294f2720b594ea126f2bfc26240f37a402b55273662910e29e0b3066dc047ea":[19,10,5,13,3],
+"group__unibase.html#gga91294f2720b594ea126f2bfc26240f37a76227e24f97b2227fdb9fd44110a42dd":[19,10,5,13,1],
+"group__unibase.html#gga91294f2720b594ea126f2bfc26240f37a9fd214785131be46a71076b2c168d257":[19,10,5,13,0],
+"group__unibase.html#gga91294f2720b594ea126f2bfc26240f37ab9612b98ecb476d7a315752483cb3f1f":[19,10,5,13,2],
+"group__unibase__binding.html":[19,10,0],
+"group__unibase__binding.html#ga09dcc5daf64bddd93afc0c59e5b09add":[19,10,0,12],
+"group__unibase__binding.html#ga0a15ff32995c493b13dc994321a1666c":[19,10,0,14],
+"group__unibase__binding.html#ga0e1754fa2d1c328c4c410728c03d0c7f":[19,10,0,1],
+"group__unibase__binding.html#ga137f6d564d5d457911f58cb429824f26":[19,10,0,2],
+"group__unibase__binding.html#ga41cc601ffb591319c6e1e3aada8f696c":[19,10,0,10],
+"group__unibase__binding.html#ga4d1666a570bef2ed3f95e1031d3d355c":[19,10,0,11],
+"group__unibase__binding.html#ga515ec66dccb2dc7ff931e02c7b19e21d":[19,10,0,9],
+"group__unibase__binding.html#ga91ebccc835b809a1e1a789e81bce7eb5":[19,10,0,5],
+"group__unibase__binding.html#gab3bb96e7227f62e90eb42b766677f481":[19,10,0,8],
+"group__unibase__binding.html#gabce0fd1ddd8c9bc3a299270224010cbb":[19,10,0,6],
+"group__unibase__binding.html#gac6e9f8d7c8578559267fec0ef515fa4f":[19,10,0,13],
+"group__unibase__binding.html#gad044c42e9ae9dc103d1a229897f7c1f9":[19,10,0,4],
+"group__unibase__binding.html#gadc26ec722ab2a2d03eb0c62b41292485":[19,10,0,3],
+"group__unibase__binding.html#gadff47c7aab721d52b327a46a9d534a8f":[19,10,0,7],
+"group__unibase__macros.html":[19,10,7],
+"group__unibase__macros.html#ga006c0be06d7911b34145f5170db7a031":[19,10,7,20],
+"group__unibase__macros.html#ga1355be3b638b6845ebd4c59d9b1fadb9":[19,10,7,46],
+"group__unibase__macros.html#ga16a69d69c461ec27876309013d5737fe":[19,10,7,22],
+"group__unibase__macros.html#ga18c29e41da6b246498d5c72db9f59e99":[19,10,7,15],
+"group__unibase__macros.html#ga199f188e67967c4b8a23455d56602557":[19,10,7,23],
+"group__unibase__macros.html#ga1d3b42a8307b2aee7739cc99168c9ce8":[19,10,7,5],
+"group__unibase__macros.html#ga1f74ce5bc0a8ec4a4766cb74c79d679f":[19,10,7,31],
+"group__unibase__macros.html#ga2227397b526d356631ae005175d8f065":[19,10,7,24],
+"group__unibase__macros.html#ga24b7d5ca5cdd54a19f08a2a9645e1d0f":[19,10,7,11],
+"group__unibase__macros.html#ga2b5d3bf62dc151de1738a1c49f8159ca":[19,10,7,55],
+"group__unibase__macros.html#ga3124350ecf4af6ba642bf83cae83126c":[19,10,7,1],
+"group__unibase__macros.html#ga31f68ff7f36940d4dfb6f0de5e0a02f3":[19,10,7,8],
+"group__unibase__macros.html#ga3e23a27a9b35057ada6800469e436f0a":[19,10,7,48],
+"group__unibase__macros.html#ga4593ad87be4823c76f66768c69491b32":[19,10,7,54],
+"group__unibase__macros.html#ga467377c918b261af9ddf79346668040a":[19,10,7,51],
+"group__unibase__macros.html#ga473a890bf9a58a5b43fe3c37e3f00fd9":[19,10,7,7],
+"group__unibase__macros.html#ga4a48c05c904260ebb1684c1edb7da9ff":[19,10,7,50],
+"group__unibase__macros.html#ga51167e539b6ff980a5129a84e336c920":[19,10,7,14],
+"group__unibase__macros.html#ga587f1bc266b17723c7184fdea56510ef":[19,10,7,38],
+"group__unibase__macros.html#ga5c78e2b760e07deba2db35dc43e52463":[19,10,7,26],
+"group__unibase__macros.html#ga62353a576054f62704d0d59abcd193be":[19,10,7,45],
+"group__unibase__macros.html#ga65e2a0b6d523e04343633ce7025c9225":[19,10,7,30],
+"group__unibase__macros.html#ga7b9bee7da2fa2ae8eaa7bd3b2e5b8d83":[19,10,7,32],
+"group__unibase__macros.html#ga7d82c9728c945550262072e037f36afe":[19,10,7,19],
+"group__unibase__macros.html#ga842fe1f7f1ff0e6f876a7cfe8da99d04":[19,10,7,35],
+"group__unibase__macros.html#ga84a5af190374ee8bcf28edc7a7859206":[19,10,7,37],
+"group__unibase__macros.html#ga875349cf7464b407da631ce16d703285":[19,10,7,3],
+"group__unibase__macros.html#ga8815d2bfe465a27972b2a602145ef448":[19,10,7,9],
+"group__unibase__macros.html#ga8b12f8b9a6993ca66403d7d88e8ccdb3":[19,10,7,13],
+"group__unibase__macros.html#ga90c0faeed3479ed38a7a25fe842abd9a":[19,10,7,2],
+"group__unibase__macros.html#ga9513a1089f4757359f5756cf5c45b3cf":[19,10,7,41],
+"group__unibase__macros.html#ga95d9894436a7d86f9486c6a8c7976db0":[19,10,7,34],
+"group__unibase__macros.html#ga96ef9f0024e36f66adec5e30434d1e0d":[19,10,7,25],
+"group__unibase__macros.html#ga9a98522dec8d461286fcc7c90e77c574":[19,10,7,12],
+"group__unibase__macros.html#ga9cc94765634b0dd573f61ea4d9e29da6":[19,10,7,42],
+"group__unibase__macros.html#gaa1ce3e797c008d4fdf40fd54d605a558":[19,10,7,28],
+"group__unibase__macros.html#gaa30b0bc68e28716f5ac1abcd4abcc28c":[19,10,7,49],
+"group__unibase__macros.html#gaac36e4b36eb9f1d1eb2603cd37a7a3fb":[19,10,7,21],
+"group__unibase__macros.html#gaad20d82fd061078263476500859d4b69":[19,10,7,18],
+"group__unibase__macros.html#gaae8c6bde84b5f7310ea4b7cc0e295fff":[19,10,7,6],
+"group__unibase__macros.html#gaaeeebb2df6a3e03034875d9daa50bc24":[19,10,7,16],
+"group__unibase__macros.html#gabae78f799148eca9e342e11e2a591a7d":[19,10,7,27],
+"group__unibase__macros.html#gac11a1ecc33e77a90670fe7fd9feccce0":[19,10,7,29],
+"group__unibase__macros.html#gac11a34967d24748090381e7fa4b7cb6e":[19,10,7,44],
+"group__unibase__macros.html#gac39981641e59b1dc6a97073fc50dfdc7":[19,10,7,47],
+"group__unibase__macros.html#gacf9a04d6aa3370592d09d0c81bd59f23":[19,10,7,17],
+"group__unibase__macros.html#gad052b9e1f7458a222840f9bae5706c12":[19,10,7,10],
+"group__unibase__macros.html#gad903fac8be9cc3549b3c367bc905a9fa":[19,10,7,33],
+"group__unibase__macros.html#gadf419dd59fd41a7600ea89f27929a059":[19,10,7,40],
 "group__unibase__macros.html#gae1788071e1d319888f7418fe949d3c31":[19,10,7,52],
 "group__unibase__macros.html#gae7e40a4663459d8c189b5bf7a72fb15b":[19,10,7,4],
 "group__unibase__macros.html#gae8de01dee2ddb7e5d116f5b44e6f8a20":[19,10,7,36],
@@ -146,108 +249,5 @@ var NAVTREEINDEX54 =
 "structCANFD__MCANECCErrStatus.html#a7451364795c4285a74b08e1131e6759f":[19,7,2,10,4],
 "structCANFD__MCANErrCntStatus.html":[19,7,2,7],
 "structCANFD__MCANErrCntStatus.html#a4beb72be3c246c1a255125309560fd33":[19,7,2,7,3],
-"structCANFD__MCANErrCntStatus.html#aa639651ffa923561145cf62c758dd732":[19,7,2,7,2],
-"structCANFD__MCANErrCntStatus.html#ad70e9c89629fa729773948e6d961925e":[19,7,2,7,1],
-"structCANFD__MCANErrCntStatus.html#af75a35934d11912843413da722aa1195":[19,7,2,7,0],
-"structCANFD__MCANGlobalFiltConfig.html":[19,7,2,4],
-"structCANFD__MCANGlobalFiltConfig.html#a2618c87d68d9f84bfe749ce039c67e19":[19,7,2,4,0],
-"structCANFD__MCANGlobalFiltConfig.html#a94bf5cd05656f477485d026a54eeb5d7":[19,7,2,4,1],
-"structCANFD__MCANGlobalFiltConfig.html#aa4eac76fe0647642bee44cf159592c2d":[19,7,2,4,3],
-"structCANFD__MCANGlobalFiltConfig.html#aa6c15be4c28519c7b04377c2ee569fd1":[19,7,2,4,2],
-"structCANFD__MCANLoopbackCfgParams.html":[19,7,2,1],
-"structCANFD__MCANLoopbackCfgParams.html#a6adc0def361017e514d3141f8f13fd30":[19,7,2,1,0],
-"structCANFD__MCANLoopbackCfgParams.html#a9edc5aa51301fb50e2419a67b5f93c44":[19,7,2,1,1],
-"structCANFD__MCANMsgObjectStats.html":[19,7,2,20],
-"structCANFD__MCANMsgObjectStats.html#a6959baad8c4cae60caf6ae60598ee0eb":[19,7,2,20,1],
-"structCANFD__MCANMsgObjectStats.html#aae81c855e2cbd8ff1784be8a76f546d5":[19,7,2,20,5],
-"structCANFD__MCANMsgObjectStats.html#ad31a4f7c4513d99650d88f0fca0f4347":[19,7,2,20,0],
-"structCANFD__MCANMsgObjectStats.html#ae1c64874a7e1d800fcff7ccf5356ab19":[19,7,2,20,2],
-"structCANFD__MCANMsgObjectStats.html#ae1e55d39f3f3df4028d3a68a2b063533":[19,7,2,20,4],
-"structCANFD__MCANMsgObjectStats.html#ae7de0dfc164060fb5671a1cf7ffc4902":[19,7,2,20,3],
-"structCANFD__MCANMsgRAMCfgParams.html":[19,7,2,5],
-"structCANFD__MCANMsgRAMCfgParams.html#a13283b50bc8d8daba2333757a1e69264":[19,7,2,5,8],
-"structCANFD__MCANMsgRAMCfgParams.html#a1d9509e65ce6831fe4eca3aef319fa08":[19,7,2,5,0],
-"structCANFD__MCANMsgRAMCfgParams.html#a34027a2166d84a7f5115c970d6f5c00c":[19,7,2,5,10],
-"structCANFD__MCANMsgRAMCfgParams.html#a373f019134783611ea5f8da2b0fa502c":[19,7,2,5,2],
-"structCANFD__MCANMsgRAMCfgParams.html#a542fe6adeafad9b21ff859eebd126cef":[19,7,2,5,11],
-"structCANFD__MCANMsgRAMCfgParams.html#a58c8fd2dd9b545c10880ba52fa767e94":[19,7,2,5,1],
-"structCANFD__MCANMsgRAMCfgParams.html#a8d57566eb75ef4d3aea389a10f8069f6":[19,7,2,5,7],
-"structCANFD__MCANMsgRAMCfgParams.html#a93b74f583b0491f402472154259a9a7e":[19,7,2,5,3],
-"structCANFD__MCANMsgRAMCfgParams.html#ab7da4f08a1e24254676a8039b4abd4df":[19,7,2,5,12],
-"structCANFD__MCANMsgRAMCfgParams.html#ace00958553250e7e7230f005e5e1ac4b":[19,7,2,5,5],
-"structCANFD__MCANMsgRAMCfgParams.html#ad6e78c49a69fd4b70589ba4b7aae34b9":[19,7,2,5,4],
-"structCANFD__MCANMsgRAMCfgParams.html#af581f302388ed194da34ded7c88d427b":[19,7,2,5,6],
-"structCANFD__MCANMsgRAMCfgParams.html#afc2280780e4e19d1b5f061b958821e8e":[19,7,2,5,9],
-"structCANFD__MCANProtocolStatus.html":[19,7,2,8],
-"structCANFD__MCANProtocolStatus.html#a180217130b2ab2840d006b3183bbe1f4":[19,7,2,8,7],
-"structCANFD__MCANProtocolStatus.html#a1edaef8890f15555df13bdf930d29f75":[19,7,2,8,2],
-"structCANFD__MCANProtocolStatus.html#a291e6eda0d33c3393e3deca7b34abc28":[19,7,2,8,9],
-"structCANFD__MCANProtocolStatus.html#a396affe709200b68654a5d6bdbd28e35":[19,7,2,8,6],
-"structCANFD__MCANProtocolStatus.html#a7751dab5f3a9e853d67421dca31a2793":[19,7,2,8,1],
-"structCANFD__MCANProtocolStatus.html#a7fb6da9660c344cf2d18097f1c319d71":[19,7,2,8,3],
-"structCANFD__MCANProtocolStatus.html#a81c7780fba1e43db6762bc1281fd7173":[19,7,2,8,8],
-"structCANFD__MCANProtocolStatus.html#a94c238cdcb8cdf0aebb37c07f84c11ef":[19,7,2,8,4],
-"structCANFD__MCANProtocolStatus.html#aa57ab859b2261f8d68ef696f2c24a60c":[19,7,2,8,10],
-"structCANFD__MCANProtocolStatus.html#ac7e906d9474aa83ae3d92e3346d5d27d":[19,7,2,8,0],
-"structCANFD__MCANProtocolStatus.html#ae6bb6741f97f3aa90f2a9f6e1d24a226":[19,7,2,8,5],
-"structCANFD__MCANTdcConfig.html":[19,7,2,3],
-"structCANFD__MCANTdcConfig.html#a146ba03ceef72bf7a8eb3d63cf5c2c63":[19,7,2,3,1],
-"structCANFD__MCANTdcConfig.html#a48a552d0cade931d186d0995e2295e2d":[19,7,2,3,0],
-"structCANFD__MessageObject.html":[19,7,2,19],
-"structCANFD__MessageObject.html#a07ac09835f2174afc2d1285abe456176":[19,7,2,19,7],
-"structCANFD__MessageObject.html#a0c30fa7f9b8b4d1c45cbe7574790ebd1":[19,7,2,19,8],
-"structCANFD__MessageObject.html#a214d487a1b44ff675820922ab9c59e7c":[19,7,2,19,15],
-"structCANFD__MessageObject.html#a2e9cb35c6c759b60e252b3b72d2da029":[19,7,2,19,0],
-"structCANFD__MessageObject.html#a2ede2a73942854ebea846cccb167e441":[19,7,2,19,17],
-"structCANFD__MessageObject.html#a45bc3c8673870f00de5c4272b96cfaaf":[19,7,2,19,2],
-"structCANFD__MessageObject.html#a4c8a119763792d013b21e7c533f82897":[19,7,2,19,6],
-"structCANFD__MessageObject.html#a584158725aa21f94c4b731c4abcbfad9":[19,7,2,19,1],
-"structCANFD__MessageObject.html#a6994f1c8a22dc3faddc973391b9ed6ea":[19,7,2,19,3],
-"structCANFD__MessageObject.html#a7971620f5b7ef97a95f9ffeabd2364df":[19,7,2,19,12],
-"structCANFD__MessageObject.html#a9506118ddad54396f4bbf978afb5233d":[19,7,2,19,5],
-"structCANFD__MessageObject.html#a9fb58906ce57f1547594ba7feacb8bc8":[19,7,2,19,9],
-"structCANFD__MessageObject.html#aa31ee7bf8c9ada7e46185d4b43810139":[19,7,2,19,11],
-"structCANFD__MessageObject.html#ab1d02a27273da485890fd9f136a74247":[19,7,2,19,13],
-"structCANFD__MessageObject.html#ad90c68c0c340a94cd00a11f0223b44d8":[19,7,2,19,16],
-"structCANFD__MessageObject.html#ae78862765789e24fe56849e699b93945":[19,7,2,19,10],
-"structCANFD__MessageObject.html#aeaee9ab3bc49493512df3fb135b90b5a":[19,7,2,19,4],
-"structCANFD__MessageObject.html#affb742b7f33e541e6aa7acf52adc0da9":[19,7,2,19,14],
-"structCANFD__Object.html":[19,7,2,15],
-"structCANFD__Object.html#a01a85ce1dcfece5a81e01ee7d8d65d9c":[19,7,2,15,20],
-"structCANFD__Object.html#a01b3a5c0b32d5c1ceae61bf74154c8cd":[19,7,2,15,0],
-"structCANFD__Object.html#a20c999d57f4f4629382da558b597b896":[19,7,2,15,8],
-"structCANFD__Object.html#a2aa7395df38daf004e50d0ab993ab505":[19,7,2,15,3],
-"structCANFD__Object.html#a3446b671fa2850cecdf3a6108dcc0d04":[19,7,2,15,6],
-"structCANFD__Object.html#a3a4c3fb18c255a530eb5ca0c40c3ae7f":[19,7,2,15,14],
-"structCANFD__Object.html#a40f6c033c4bf58ec7ed435eda4c7d36f":[19,7,2,15,25],
-"structCANFD__Object.html#a4736e9d6ec090ad8916f60e154300687":[19,7,2,15,11],
-"structCANFD__Object.html#a48ff7cba8195a6050b81ccc6260c04c8":[19,7,2,15,16],
-"structCANFD__Object.html#a53e65cc1f41cf589452cd41cd14b9b30":[19,7,2,15,9],
-"structCANFD__Object.html#a63b0e868e8d152785d9f0427de5ea516":[19,7,2,15,12],
-"structCANFD__Object.html#a64a4c8b3d03b3adf013bcdb33b2f10a6":[19,7,2,15,19],
-"structCANFD__Object.html#a66987031bcd32e270ac3a10a727d7e9b":[19,7,2,15,2],
-"structCANFD__Object.html#a68c0a40f768059446390c3fbb1ace45c":[19,7,2,15,7],
-"structCANFD__Object.html#a795e5172ca94288a5d76d512a0deb77d":[19,7,2,15,24],
-"structCANFD__Object.html#a829fc78fb5b885799318b77cc2cab03c":[19,7,2,15,21],
-"structCANFD__Object.html#a8af7f9dd0a3b8d42494702d84ad2897d":[19,7,2,15,18],
-"structCANFD__Object.html#a9424d9e3dfdf782204e9242e35910186":[19,7,2,15,10],
-"structCANFD__Object.html#aa7be93caa28db2828d9669e17642296d":[19,7,2,15,5],
-"structCANFD__Object.html#abb5fe84b0b875a1fba7cd2d4604fd650":[19,7,2,15,1],
-"structCANFD__Object.html#abcc46fc8fa9ebc10917aadf44ea3d0a7":[19,7,2,15,13],
-"structCANFD__Object.html#ad7467acc4e6859b0f6b8616fd479b3d2":[19,7,2,15,17],
-"structCANFD__Object.html#ad9aeae842f3e0e4f1b3d7f0956d1e9fa":[19,7,2,15,26],
-"structCANFD__Object.html#ae7637531f5e038b6ba79230e06ecd139":[19,7,2,15,23],
-"structCANFD__Object.html#ae78eb23f0ca1bf604d0ea60335d4ac5a":[19,7,2,15,22],
-"structCANFD__Object.html#aef51b77375604d2405718fb0107ec114":[19,7,2,15,27],
-"structCANFD__Object.html#af9a8e076064289b00c73a449f43adf76":[19,7,2,15,4],
-"structCANFD__Object.html#afbda9a6053303b652fc07d163c041501":[19,7,2,15,15],
-"structCANFD__OpenParams.html":[19,7,2,14],
-"structCANFD__OpenParams.html#a1011c8e1639f8a9c8749e1ae75f67755":[19,7,2,14,8],
-"structCANFD__OpenParams.html#a11f6be3368d8a69262ec4ffe5d9c0b0b":[19,7,2,14,10],
-"structCANFD__OpenParams.html#a1e08ee7fb8d56817d2f761a8e6e01d44":[19,7,2,14,23],
-"structCANFD__OpenParams.html#a1f87c17632ff5a5b383a4692f2444a83":[19,7,2,14,9],
-"structCANFD__OpenParams.html#a25b6bfd6771e972b0c8f283bd5898461":[19,7,2,14,4],
-"structCANFD__OpenParams.html#a29deb6f83af1bc14236fdd6d472686b2":[19,7,2,14,21],
-"structCANFD__OpenParams.html#a31dab67e9194590591ca61a14d977dbb":[19,7,2,14,6],
-"structCANFD__OpenParams.html#a3b579e92204b6466211f708820957731":[19,7,2,14,24]
+"structCANFD__MCANErrCntStatus.html#aa639651ffa923561145cf62c758dd732":[19,7,2,7,2]
 };
