@@ -1,5 +1,111 @@
 var NAVTREEINDEX59 =
 {
+"structEDMA__Params.html#aa201bda2709dbd15c15a6eb5cbe98f4a":[19,7,6,7,0],
+"structEDMA__Params.html#af0c4c90de08720b7d22b266e6eee92d5":[19,7,6,7,1],
+"structEDMA__ResourceObject.html":[19,7,6,2],
+"structEDMA__ResourceObject.html#a61de78a3f8e58678b822006dd9706d05":[19,7,6,2,3],
+"structEDMA__ResourceObject.html#a94019f1436cf0f4bf884a0f7ca183998":[19,7,6,2,2],
+"structEDMA__ResourceObject.html#abf8ed092d73ec2af22125ee31606dccb":[19,7,6,2,1],
+"structEDMA__ResourceObject.html#ae89623e32ee872837bf4165102fdbfa2":[19,7,6,2,0],
+"structEDMA__TcErrorInfo.html":[19,7,6,5],
+"structEDMA__TcErrorInfo.html#a0117a40b50600ab80d55dbc37a243172":[19,7,6,5,0],
+"structEDMA__TcErrorInfo.html#a2be45abf9b7667e0b3fc9181754e826e":[19,7,6,5,2],
+"structEDMA__TcErrorInfo.html#a4eea7044cb5fb0dae53a7b67aaa4bbde":[19,7,6,5,5],
+"structEDMA__TcErrorInfo.html#aa3005957c00e19a06a5b174c377b6579":[19,7,6,5,4],
+"structEDMA__TcErrorInfo.html#ab7dfc5e0222c4d08f6fa70a39f6d4b25":[19,7,6,5,6],
+"structEDMA__TcErrorInfo.html#afbbff955b53affc6b2599f5d53e1f055":[19,7,6,5,3],
+"structEDMA__TcErrorInfo.html#afdcaae14dbe42d6289a99e65f23f0e1a":[19,7,6,5,1],
+"structEEPROM__Attrs.html":[19,1,2,2],
+"structEEPROM__Attrs.html#ab5409dc32ab52ad52ace4a745642d97f":[19,1,2,2,2],
+"structEEPROM__Attrs.html#ab8d21b11713ce8bf7157f7a76d2cf7d1":[19,1,2,2,1],
+"structEEPROM__Attrs.html#ac6ffb051bb5551f2ab97c93278968d6f":[19,1,2,2,0],
+"structEEPROM__Config__s.html":[19,1,2,3],
+"structEEPROM__Config__s.html#a6ab9b742abfd9e214a098341d0178a0a":[19,1,2,3,0],
+"structEEPROM__Config__s.html#acb9dae722b7badaa917cb1907f171b2a":[19,1,2,3,1],
+"structEEPROM__Config__s.html#ae7c4fc69b2b0489389b25852d7e24faa":[19,1,2,3,2],
+"structEEPROM__Fxns.html":[19,1,2,1],
+"structEEPROM__Fxns.html#a080878c59f5ecf14cbbe62a3b2cff65c":[19,1,2,1,2],
+"structEEPROM__Fxns.html#a1045db6d6717d6538363052e667e01c4":[19,1,2,1,1],
+"structEEPROM__Fxns.html#a2be49cda279b71221aa7298898d929dd":[19,1,2,1,3],
+"structEEPROM__Fxns.html#a8b49c618fccd93f4a131d19f62779519":[19,1,2,1,0],
+"structEEPROM__Object.html":[19,1,2,4],
+"structEEPROM__Object.html#a648518ecd521d973da0597593c92c449":[19,1,2,4,2],
+"structEEPROM__Object.html#a8f76e10120ddf201289d110e6bf0f40c":[19,1,2,4,5],
+"structEEPROM__Object.html#a94bba1e10bab6c922ab5450a0ed8cce1":[19,1,2,4,3],
+"structEEPROM__Object.html#a9ad7ea23393a3ae5fbb3cbfcef4845d3":[19,1,2,4,0],
+"structEEPROM__Object.html#aafbb57c7343e8181e9635eb1d6e25676":[19,1,2,4,4],
+"structEEPROM__Object.html#ad8d1bfda8d1ccb9c3aa494860b58e3d4":[19,1,2,4,1],
+"structEEPROM__Params__s.html":[19,1,2,0],
+"structEEPROM__Params__s.html#a424ab348295254ac373772bf7a92b23f":[19,1,2,0,0],
+"structEEPROM__Params__s.html#a6818a21fac4c1b8750145e71dc48a8ea":[19,1,2,0,1],
+"structEPWM__SignalParams.html":[19,7,7,0],
+"structEPWM__SignalParams.html#a0052d14c4707bd75545443eda47f199e":[19,7,7,0,0],
+"structEPWM__SignalParams.html#a37194c66eb7c7a41247c4f985a12d7be":[19,7,7,0,6],
+"structEPWM__SignalParams.html#a6fe9fbf25b762fbdea949ce8e2af5d42":[19,7,7,0,2],
+"structEPWM__SignalParams.html#ab94e6f9752e9876cd76a42d5468300f1":[19,7,7,0,7],
+"structEPWM__SignalParams.html#abc589f797d6d517545628f7a702353d5":[19,7,7,0,3],
+"structEPWM__SignalParams.html#ac6e6281fd80b9750587a89ec1250b156":[19,7,7,0,5],
+"structEPWM__SignalParams.html#acf8e2fa1daeea782f8f27836550208d9":[19,7,7,0,1],
+"structEPWM__SignalParams.html#add565f72b18b00e0698ebcf2e2e2ae82":[19,7,7,0,4],
+"structEQEP__SourceSelect.html":[19,7,8,0],
+"structEQEP__SourceSelect.html#a2f88b2225ae7732b49feee3d4dbe59a5":[19,7,8,0,2],
+"structEQEP__SourceSelect.html#a36bae2e2153e0e1673c09a4eaa6d4a55":[19,7,8,0,0],
+"structEQEP__SourceSelect.html#a44f20ceece4ee9a490375ab26b6080da":[19,7,8,0,1],
+"structETHPHY__Attrs.html":[19,1,0,2],
+"structETHPHY__Attrs.html#a9a4df46a57ee9ea0bc966dfbd3a85a51":[19,1,0,2,0],
+"structETHPHY__Attrs.html#aeb591c6878818f9b25cfb10df464b498":[19,1,0,2,1],
+"structETHPHY__Config.html":[19,1,0,3],
+"structETHPHY__Config.html#a98af9c12c14d3551d8c55f3a8d957899":[19,1,0,3,0],
+"structETHPHY__Config.html#ac843bfd8305281e8873dab406fbc00f0":[19,1,0,3,1],
+"structETHPHY__Config.html#ada87356f6f69f640324f7ec243cb230d":[19,1,0,3,2],
+"structETHPHY__Fxns.html":[19,1,0,1],
+"structETHPHY__Fxns.html#a081058741e0d5cda91a68a291308b7f4":[19,1,0,1,1],
+"structETHPHY__Fxns.html#a43255508d3a6a6039b2d57a16365a467":[19,1,0,1,2],
+"structETHPHY__Fxns.html#a64cea306569fa24722ed1c86d4e9e9c2":[19,1,0,1,0],
+"structETHPHY__Params.html":[19,1,0,0],
+"structETHPHY__Params.html#af389ecbf2f1215df555b87137f75b3e6":[19,1,0,0,0],
+"structETHPHY__SpeedDuplexConfig.html":[19,1,0,4],
+"structETHPHY__SpeedDuplexConfig.html#a790b1cb3380ad6003d299028b0f64d7e":[19,1,0,4,0],
+"structEdma__IntrObject.html":[19,7,6,8],
+"structEdma__IntrObject.html#a269367fdadf3a52ed34c40def1d18d96":[19,7,6,8,4],
+"structEdma__IntrObject.html#a8ab3ef0a6376c449aaec1e1e548ddfff":[19,7,6,8,1],
+"structEdma__IntrObject.html#aa4dfd3ed797444486f8e40624d635e1c":[19,7,6,8,0],
+"structEdma__IntrObject.html#ac5490e8a31870a8fd5dc7e6b64b4a31c":[19,7,6,8,3],
+"structEdma__IntrObject.html#ad2eec23e992618bb0d6965c8bbb6ca91":[19,7,6,8,2],
+"structEnetCpdma__OpenRxChPrms.html":[19,4,0,0,0,0,12],
+"structEnetCpdma__OpenRxChPrms.html#a0961951aa692a7574b8ccb47a8ccef85":[19,4,0,0,0,0,12,4],
+"structEnetCpdma__OpenRxChPrms.html#a22b6580590c5a6c02bd21d1918e749d3":[19,4,0,0,0,0,12,0],
+"structEnetCpdma__OpenRxChPrms.html#a54e62c22d0ef0fbd7baa349ccbe45d91":[19,4,0,0,0,0,12,1],
+"structEnetCpdma__OpenRxChPrms.html#a8a14a31d130cad3712bbf0fa30552070":[19,4,0,0,0,0,12,3],
+"structEnetCpdma__OpenRxChPrms.html#adb14aac558d6abeec3f7ef53de3639d7":[19,4,0,0,0,0,12,2],
+"structEnetCpdma__OpenTxChPrms.html":[19,4,0,0,0,0,11],
+"structEnetCpdma__OpenTxChPrms.html#a157ebeb796b2ff14f6b0b9225b221253":[19,4,0,0,0,0,11,3],
+"structEnetCpdma__OpenTxChPrms.html#a2eda8a58f7e15c88551ad34de897369f":[19,4,0,0,0,0,11,0],
+"structEnetCpdma__OpenTxChPrms.html#a5cc3c83febe76501ec98f49bba886e1a":[19,4,0,0,0,0,11,2],
+"structEnetCpdma__OpenTxChPrms.html#a97ef204e1173c3217f2896360b3ca92b":[19,4,0,0,0,0,11,1],
+"structEnetCpdma__OpenTxChPrms.html#ae5a6ec768aa63f2b8ff57f935d5c6a49":[19,4,0,0,0,0,11,4],
+"structEnetCpdma__PktInfo.html":[19,4,0,0,0,1,3],
+"structEnetCpdma__PktInfo.html#a0220cf2037ae0782e2a1a4ebd079d12d":[19,4,0,0,0,1,3,7],
+"structEnetCpdma__PktInfo.html#a19a1ef4192dd90c65033153d2ffaeec6":[19,4,0,0,0,1,3,2],
+"structEnetCpdma__PktInfo.html#a3b647ff7ff1f77a16a036d11bcbb0aa4":[19,4,0,0,0,1,3,8],
+"structEnetCpdma__PktInfo.html#a69c51fab0f0c55097cbda464eff81cae":[19,4,0,0,0,1,3,4],
+"structEnetCpdma__PktInfo.html#a875740da8e825c6a8bd505987d32955f":[19,4,0,0,0,1,3,6],
+"structEnetCpdma__PktInfo.html#a8933eb3ae4f1ae7df2812b53b18db914":[19,4,0,0,0,1,3,5],
+"structEnetCpdma__PktInfo.html#aadfe8fbf8f60b0b8558dd8f96982c89d":[19,4,0,0,0,1,3,1],
+"structEnetCpdma__PktInfo.html#ace452b20f6c12dadac79909832cc153c":[19,4,0,0,0,1,3,0],
+"structEnetCpdma__PktInfo.html#adb3d1a43ffa21f566bf863dc4088ebdf":[19,4,0,0,0,1,3,9],
+"structEnetCpdma__PktInfo.html#af1c0851125b4b066c3cfcadcb4f821a4":[19,4,0,0,0,1,3,3],
+"structEnetCpdma__PktTsInfo.html":[19,4,0,0,0,1,0],
+"structEnetCpdma__PktTsInfo.html#a1cfd1ab09edf9e5a95f65965bf5aa658":[19,4,0,0,0,1,0,4],
+"structEnetCpdma__PktTsInfo.html#a420ea5a26109ac0462c4623442b31142":[19,4,0,0,0,1,0,3],
+"structEnetCpdma__PktTsInfo.html#a42304847ac397a182b573a7547cff1ca":[19,4,0,0,0,1,0,1],
+"structEnetCpdma__PktTsInfo.html#a6d8a07bb1dcccc55127f9c4d11ccdc8e":[19,4,0,0,0,1,0,0],
+"structEnetCpdma__PktTsInfo.html#ac220b6ff138a7504fbe06012a063cdd9":[19,4,0,0,0,1,0,2],
+"structEnetCpdma__RxChInitPrms.html":[19,4,0,0,0,0,13],
+"structEnetCpdma__RxChInitPrms.html#aaa01da4b4298ae8ac5861445a8e07f7d":[19,4,0,0,0,0,13,0],
+"structEnetCpdma__SGList.html":[19,4,0,0,0,1,2],
+"structEnetCpdma__SGList.html#a8668490ca984d48c81938aeab9b611ac":[19,4,0,0,0,1,2,0],
+"structEnetCpdma__SGList.html#a96ad9aad37b112b7d561c7d5eaf9cc30":[19,4,0,0,0,1,2,1],
 "structEnetCpdma__SGListEntry.html":[19,4,0,0,0,1,1],
 "structEnetCpdma__SGListEntry.html#a19607f9a04a50c2039c86bc6a2919f83":[19,4,0,0,0,1,1,0],
 "structEnetCpdma__SGListEntry.html#a38f22dc244d844d635088672ee921a46":[19,4,0,0,0,1,1,1],
@@ -143,111 +249,5 @@ var NAVTREEINDEX59 =
 "structEnetPhy__Obj.html#ab09f1f4d15d40dae95f9246946646308":[19,4,0,13,8,11],
 "structEnetPhy__Obj.html#aba5c2a6c65120737b943ac37b418f850":[19,4,0,13,8,0],
 "structEnetPhy__Obj.html#abbd01b6771dfd8fd1b87868e208bd672":[19,4,0,13,8,5],
-"structEnetPhy__Obj.html#acf0b022b5945134c1be9da34f3fc7f1f":[19,4,0,13,8,2],
-"structEnetPhy__Obj.html#ad277b7ca1134d1809919408a5cfaf413":[19,4,0,13,8,9],
-"structEnetPhy__Obj.html#af83aae079158fbe8b3afc28d081fb64c":[19,4,0,13,8,4],
-"structEnetPhy__Obj.html#aff6e978a83b3fb6cb928935e52148348":[19,4,0,13,8,3],
-"structEnetPhy__State.html":[19,4,0,13,7],
-"structEnetPhy__State.html#a23a7141dcb00f4ab2b794d79e391e783":[19,4,0,13,7,3],
-"structEnetPhy__State.html#a316597661ce5b376055576b0ba418f23":[19,4,0,13,7,9],
-"structEnetPhy__State.html#a32418e706ff4269251c83fb5334996d4":[19,4,0,13,7,1],
-"structEnetPhy__State.html#a35921dba6384be1f92b8f4ea6be4310a":[19,4,0,13,7,14],
-"structEnetPhy__State.html#a39b049fcdfea083c6cdbcfa3cba7ace7":[19,4,0,13,7,4],
-"structEnetPhy__State.html#a73d5167bee62e74f6eda098de55fa34e":[19,4,0,13,7,6],
-"structEnetPhy__State.html#a751e401d0f33865065206a3f52bf48ac":[19,4,0,13,7,7],
-"structEnetPhy__State.html#a7a1b87ae30afd4973a78214cc587ff5f":[19,4,0,13,7,0],
-"structEnetPhy__State.html#a7ccd637c31cbec932a42f981853c0ede":[19,4,0,13,7,12],
-"structEnetPhy__State.html#a8ecd44bb2e8fd8298d0c5f4be2d8dc72":[19,4,0,13,7,10],
-"structEnetPhy__State.html#a9fc95905371b64b198e447e4307c6819":[19,4,0,13,7,8],
-"structEnetPhy__State.html#abb3651617caed1c0ba14a76e728f3858":[19,4,0,13,7,5],
-"structEnetPhy__State.html#ace7377bc77b85a643c240ff4d3dc652b":[19,4,0,13,7,13],
-"structEnetPhy__State.html#ace82b4fdcdd6dff56479412c9f6323d3":[19,4,0,13,7,2],
-"structEnetPhy__State.html#affcdf8170795dd5e245eb28f1f31ba3c":[19,4,0,13,7,11],
-"structEnetPhy__Version.html":[19,4,0,13,2],
-"structEnetPhy__Version.html#a6761be25acfe02923d1569b74ce1a25d":[19,4,0,13,2,1],
-"structEnetPhy__Version.html#ae4e18e89df0c29baae6eabcd87d89092":[19,4,0,13,2,2],
-"structEnetPhy__Version.html#ae508bfdc1dffd61a5dc5ac04fd9c52a1":[19,4,0,13,2,0],
-"structEnetQ.html":[19,4,0,7,1],
-"structEnetQ.html#a161c7fb022c75decb8ec4f5ca5f7ee57":[19,4,0,7,1,1],
-"structEnetQ.html#a9bcf5ec887e25424c14fa9e537e4bb20":[19,4,0,7,1,2],
-"structEnetQ.html#ad7175db4dec96f857742561e585fd70a":[19,4,0,7,1,3],
-"structEnetQ.html#ae652e20f61360d94c329713de4406231":[19,4,0,7,1,0],
-"structEnetQ__Node.html":[19,4,0,7,0],
-"structEnetQ__Node.html#a6002e45357c59caf2afdc0eb34107f21":[19,4,0,7,0,0],
-"structEnetRm__AllocHwPushOutArgs.html":[19,4,0,8,12],
-"structEnetRm__AllocHwPushOutArgs.html#a3c930a2af871fd575f9d0ed90bc7dcb1":[19,4,0,8,12,0],
-"structEnetRm__AllocMacAddrOutArgs.html":[19,4,0,8,7],
-"structEnetRm__AllocMacAddrOutArgs.html#ad6ccb4ff9f9a1c8ebbb5da31553f1a6f":[19,4,0,8,7,0],
-"structEnetRm__AllocRxFlow.html":[19,4,0,8,6],
-"structEnetRm__AllocRxFlow.html#ac59a0dc8031ceb00a92a4f66060e5f24":[19,4,0,8,6,1],
-"structEnetRm__AllocRxFlow.html#ac9ed8efcaaa608c7ce0f95b28e10e66a":[19,4,0,8,6,0],
-"structEnetRm__AllocRxFlowInArgs.html":[19,4,0,8,5],
-"structEnetRm__AllocRxFlowInArgs.html#a2704f1f39821355ae442e08774d3692e":[19,4,0,8,5,1],
-"structEnetRm__AllocRxFlowInArgs.html#a848ce236d3374fbe98452c50c4244357":[19,4,0,8,5,0],
-"structEnetRm__FreeHwPushInArgs.html":[19,4,0,8,13],
-"structEnetRm__FreeHwPushInArgs.html#a772231ca554371265c59ff9eddb629a4":[19,4,0,8,13,0],
-"structEnetRm__FreeHwPushInArgs.html#a9bbe9ae871ca3980c3c7ff16665c2eb2":[19,4,0,8,13,1],
-"structEnetRm__FreeMacAddrInArgs.html":[19,4,0,8,10],
-"structEnetRm__FreeMacAddrInArgs.html#a8a8324f90da7fb358eba06f588fad884":[19,4,0,8,10,1],
-"structEnetRm__FreeMacAddrInArgs.html#ab5aaebd0400086ed85cd33bd5dd33215":[19,4,0,8,10,0],
-"structEnetRm__FreeRxFlowInArgs.html":[19,4,0,8,9],
-"structEnetRm__FreeRxFlowInArgs.html#a58e5540082d25f5785295737474fad5a":[19,4,0,8,9,2],
-"structEnetRm__FreeRxFlowInArgs.html#a5950ea7268b4ec99676aabbad6e999df":[19,4,0,8,9,0],
-"structEnetRm__FreeRxFlowInArgs.html#aa14ccdd7888172a0793471083ac3d73b":[19,4,0,8,9,1],
-"structEnetRm__FreeTxChInArgs.html":[19,4,0,8,8],
-"structEnetRm__FreeTxChInArgs.html#a31f2dba4b9dfe443f253c8ed48a149d3":[19,4,0,8,8,1],
-"structEnetRm__FreeTxChInArgs.html#a81aad5fef388841b169ffea5fe49c563":[19,4,0,8,8,0],
-"structEnetRm__IoctlPermissionEntry.html":[19,4,0,8,2],
-"structEnetRm__IoctlPermissionEntry.html#a11ceb4fbd18af1ba763af51ca189e278":[19,4,0,8,2,1],
-"structEnetRm__IoctlPermissionEntry.html#a638b0ba77ad9e399557e0cf1708fecfb":[19,4,0,8,2,0],
-"structEnetRm__IoctlPermissionTable.html":[19,4,0,8,3],
-"structEnetRm__IoctlPermissionTable.html#a07fd410ca2f791b50d3a756132d35c6c":[19,4,0,8,3,2],
-"structEnetRm__IoctlPermissionTable.html#a08071053bd1c71ea3e32d8a2eee43206":[19,4,0,8,3,1],
-"structEnetRm__IoctlPermissionTable.html#a959d5d4388d3ccb68067878eba580cd5":[19,4,0,8,3,0],
-"structEnetRm__MacAddressPool.html":[19,4,0,8,4],
-"structEnetRm__MacAddressPool.html#a07bcf0aacbdea04bef6324c9eff70109":[19,4,0,8,4,1],
-"structEnetRm__MacAddressPool.html#ad5c5b9ceccab4d022fea1a478df30689":[19,4,0,8,4,0],
-"structEnetRm__ResCfg.html":[19,4,0,8,11],
-"structEnetRm__ResCfg.html#a060249de4994fa4b50e85b9233937ca9":[19,4,0,8,11,2],
-"structEnetRm__ResCfg.html#a2ef2471c706c266c660b6739d3d50645":[19,4,0,8,11,0],
-"structEnetRm__ResCfg.html#adddefa12afa409bab36d2b975fd5288f":[19,4,0,8,11,1],
-"structEnetRm__ResCfg.html#ae54273010da9be21a4d88cc5068c6a5d":[19,4,0,8,11,3],
-"structEnetRm__ResPrms.html":[19,4,0,8,1],
-"structEnetRm__ResPrms.html#a18319e47b19a59eff8e556adf9ade3c4":[19,4,0,8,1,2],
-"structEnetRm__ResPrms.html#ab3e6e5e694a5a18f06347d502a9c3b5a":[19,4,0,8,1,1],
-"structEnetRm__ResPrms.html#aef5c0203b0c02afc893b6adfc6b754e7":[19,4,0,8,1,0],
-"structEnetRm__ResourceInfo.html":[19,4,0,8,0],
-"structEnetRm__ResourceInfo.html#a0a549dc877888817d6aee43713be5cb0":[19,4,0,8,0,4],
-"structEnetRm__ResourceInfo.html#a1018833da2e0120f2d3a00320704f507":[19,4,0,8,0,0],
-"structEnetRm__ResourceInfo.html#a94354ed8c2c70f99a9b8e89f374480af":[19,4,0,8,0,6],
-"structEnetRm__ResourceInfo.html#a9ef765ed82439a8b68b464d31f462d12":[19,4,0,8,0,5],
-"structEnetRm__ResourceInfo.html#aca13bcc9d04dbc098caaf26c85c5b62b":[19,4,0,8,0,3],
-"structEnetRm__ResourceInfo.html#adbbe5905f0481575d6175963e888ec0e":[19,4,0,8,0,1],
-"structEnetRm__ResourceInfo.html#aed6a2ca6840471e320d24dc40060e65a":[19,4,0,8,0,2],
-"structEnetTas__ConfigStatus.html":[19,4,0,10,4],
-"structEnetTas__ConfigStatus.html#a78eddac209d9894138d1da3864fe5ca5":[19,4,0,10,4,3],
-"structEnetTas__ConfigStatus.html#a85ec84f75224e9b79ada92c92cb941e6":[19,4,0,10,4,1],
-"structEnetTas__ConfigStatus.html#a982f02ae305abc26358f7efc761ea13f":[19,4,0,10,4,2],
-"structEnetTas__ConfigStatus.html#aa8429bbbe6fcf17d55eee10f8f85700c":[19,4,0,10,4,0],
-"structEnetTas__ControlList.html":[19,4,0,10,3],
-"structEnetTas__ControlList.html#a7f406efcb3b84f71ada4a61c9b3ea63f":[19,4,0,10,3,0],
-"structEnetTas__ControlList.html#ab3c74ff9df91f1c1bb2df040cfb2be62":[19,4,0,10,3,4],
-"structEnetTas__ControlList.html#ab6866461954473b6dbd7aa9db1f0a11e":[19,4,0,10,3,1],
-"structEnetTas__ControlList.html#afd4da3b610a5ee1f2cae3ab64673c471":[19,4,0,10,3,3],
-"structEnetTas__ControlList.html#afffb7eefd4adf29b44118ed1680ad1c1":[19,4,0,10,3,2],
-"structEnetTas__GateCmdEntry.html":[19,4,0,10,1],
-"structEnetTas__GateCmdEntry.html#a57f99e69caecba000ccd2f335679e5b1":[19,4,0,10,1,1],
-"structEnetTas__GateCmdEntry.html#aff1551bcc2ee532b086dff45c34aef3d":[19,4,0,10,1,0],
-"structEnetTas__GenericInArgs.html":[19,4,0,10,0],
-"structEnetTas__GenericInArgs.html#a17834e505e843f0eb74e881cd9e0a449":[19,4,0,10,0,0],
-"structEnetTas__MaxSDUTable.html":[19,4,0,10,2],
-"structEnetTas__MaxSDUTable.html#a9fd88c77a7487ecf296c978add06ac68":[19,4,0,10,2,0],
-"structEnetTas__SetAdminListInArgs.html":[19,4,0,10,5],
-"structEnetTas__SetAdminListInArgs.html#a11e5ef5ce0cc9bad4fad5cf9a91c0ae1":[19,4,0,10,5,1],
-"structEnetTas__SetAdminListInArgs.html#ac3cc8e5396da01b75d06639b43048b55":[19,4,0,10,5,0],
-"structEnetTas__SetStateInArgs.html":[19,4,0,10,6],
-"structEnetTas__SetStateInArgs.html#a077d944a8c8b30138621c8ec2607df04":[19,4,0,10,6,1],
-"structEnetTas__SetStateInArgs.html#ab316768c3c85cf4c28c189443f805f0c":[19,4,0,10,6,0],
-"structEnetTimeSync__GetEthTimestampInArgs.html":[19,4,0,11,4],
-"structEnetTimeSync__GetEthTimestampInArgs.html#a5eb987a8093cb7762d1210a5cbca7558":[19,4,0,11,4,1]
+"structEnetPhy__Obj.html#acf0b022b5945134c1be9da34f3fc7f1f":[19,4,0,13,8,2]
 };
