@@ -1,5 +1,111 @@
 var NAVTREEINDEX60 =
 {
+"structEnetPhy__Obj.html#ad277b7ca1134d1809919408a5cfaf413":[19,4,0,13,8,9],
+"structEnetPhy__Obj.html#af83aae079158fbe8b3afc28d081fb64c":[19,4,0,13,8,4],
+"structEnetPhy__Obj.html#aff6e978a83b3fb6cb928935e52148348":[19,4,0,13,8,3],
+"structEnetPhy__State.html":[19,4,0,13,7],
+"structEnetPhy__State.html#a23a7141dcb00f4ab2b794d79e391e783":[19,4,0,13,7,3],
+"structEnetPhy__State.html#a316597661ce5b376055576b0ba418f23":[19,4,0,13,7,9],
+"structEnetPhy__State.html#a32418e706ff4269251c83fb5334996d4":[19,4,0,13,7,1],
+"structEnetPhy__State.html#a35921dba6384be1f92b8f4ea6be4310a":[19,4,0,13,7,14],
+"structEnetPhy__State.html#a39b049fcdfea083c6cdbcfa3cba7ace7":[19,4,0,13,7,4],
+"structEnetPhy__State.html#a73d5167bee62e74f6eda098de55fa34e":[19,4,0,13,7,6],
+"structEnetPhy__State.html#a751e401d0f33865065206a3f52bf48ac":[19,4,0,13,7,7],
+"structEnetPhy__State.html#a7a1b87ae30afd4973a78214cc587ff5f":[19,4,0,13,7,0],
+"structEnetPhy__State.html#a7ccd637c31cbec932a42f981853c0ede":[19,4,0,13,7,12],
+"structEnetPhy__State.html#a8ecd44bb2e8fd8298d0c5f4be2d8dc72":[19,4,0,13,7,10],
+"structEnetPhy__State.html#a9fc95905371b64b198e447e4307c6819":[19,4,0,13,7,8],
+"structEnetPhy__State.html#abb3651617caed1c0ba14a76e728f3858":[19,4,0,13,7,5],
+"structEnetPhy__State.html#ace7377bc77b85a643c240ff4d3dc652b":[19,4,0,13,7,13],
+"structEnetPhy__State.html#ace82b4fdcdd6dff56479412c9f6323d3":[19,4,0,13,7,2],
+"structEnetPhy__State.html#affcdf8170795dd5e245eb28f1f31ba3c":[19,4,0,13,7,11],
+"structEnetPhy__Version.html":[19,4,0,13,2],
+"structEnetPhy__Version.html#a6761be25acfe02923d1569b74ce1a25d":[19,4,0,13,2,1],
+"structEnetPhy__Version.html#ae4e18e89df0c29baae6eabcd87d89092":[19,4,0,13,2,2],
+"structEnetPhy__Version.html#ae508bfdc1dffd61a5dc5ac04fd9c52a1":[19,4,0,13,2,0],
+"structEnetQ.html":[19,4,0,7,1],
+"structEnetQ.html#a161c7fb022c75decb8ec4f5ca5f7ee57":[19,4,0,7,1,1],
+"structEnetQ.html#a9bcf5ec887e25424c14fa9e537e4bb20":[19,4,0,7,1,2],
+"structEnetQ.html#ad7175db4dec96f857742561e585fd70a":[19,4,0,7,1,3],
+"structEnetQ.html#ae652e20f61360d94c329713de4406231":[19,4,0,7,1,0],
+"structEnetQ__Node.html":[19,4,0,7,0],
+"structEnetQ__Node.html#a6002e45357c59caf2afdc0eb34107f21":[19,4,0,7,0,0],
+"structEnetRm__AllocHwPushOutArgs.html":[19,4,0,8,12],
+"structEnetRm__AllocHwPushOutArgs.html#a3c930a2af871fd575f9d0ed90bc7dcb1":[19,4,0,8,12,0],
+"structEnetRm__AllocMacAddrOutArgs.html":[19,4,0,8,7],
+"structEnetRm__AllocMacAddrOutArgs.html#ad6ccb4ff9f9a1c8ebbb5da31553f1a6f":[19,4,0,8,7,0],
+"structEnetRm__AllocRxFlow.html":[19,4,0,8,6],
+"structEnetRm__AllocRxFlow.html#ac59a0dc8031ceb00a92a4f66060e5f24":[19,4,0,8,6,1],
+"structEnetRm__AllocRxFlow.html#ac9ed8efcaaa608c7ce0f95b28e10e66a":[19,4,0,8,6,0],
+"structEnetRm__AllocRxFlowInArgs.html":[19,4,0,8,5],
+"structEnetRm__AllocRxFlowInArgs.html#a2704f1f39821355ae442e08774d3692e":[19,4,0,8,5,1],
+"structEnetRm__AllocRxFlowInArgs.html#a848ce236d3374fbe98452c50c4244357":[19,4,0,8,5,0],
+"structEnetRm__FreeHwPushInArgs.html":[19,4,0,8,13],
+"structEnetRm__FreeHwPushInArgs.html#a772231ca554371265c59ff9eddb629a4":[19,4,0,8,13,0],
+"structEnetRm__FreeHwPushInArgs.html#a9bbe9ae871ca3980c3c7ff16665c2eb2":[19,4,0,8,13,1],
+"structEnetRm__FreeMacAddrInArgs.html":[19,4,0,8,10],
+"structEnetRm__FreeMacAddrInArgs.html#a8a8324f90da7fb358eba06f588fad884":[19,4,0,8,10,1],
+"structEnetRm__FreeMacAddrInArgs.html#ab5aaebd0400086ed85cd33bd5dd33215":[19,4,0,8,10,0],
+"structEnetRm__FreeRxFlowInArgs.html":[19,4,0,8,9],
+"structEnetRm__FreeRxFlowInArgs.html#a58e5540082d25f5785295737474fad5a":[19,4,0,8,9,2],
+"structEnetRm__FreeRxFlowInArgs.html#a5950ea7268b4ec99676aabbad6e999df":[19,4,0,8,9,0],
+"structEnetRm__FreeRxFlowInArgs.html#aa14ccdd7888172a0793471083ac3d73b":[19,4,0,8,9,1],
+"structEnetRm__FreeTxChInArgs.html":[19,4,0,8,8],
+"structEnetRm__FreeTxChInArgs.html#a31f2dba4b9dfe443f253c8ed48a149d3":[19,4,0,8,8,1],
+"structEnetRm__FreeTxChInArgs.html#a81aad5fef388841b169ffea5fe49c563":[19,4,0,8,8,0],
+"structEnetRm__IoctlPermissionEntry.html":[19,4,0,8,2],
+"structEnetRm__IoctlPermissionEntry.html#a11ceb4fbd18af1ba763af51ca189e278":[19,4,0,8,2,1],
+"structEnetRm__IoctlPermissionEntry.html#a638b0ba77ad9e399557e0cf1708fecfb":[19,4,0,8,2,0],
+"structEnetRm__IoctlPermissionTable.html":[19,4,0,8,3],
+"structEnetRm__IoctlPermissionTable.html#a07fd410ca2f791b50d3a756132d35c6c":[19,4,0,8,3,2],
+"structEnetRm__IoctlPermissionTable.html#a08071053bd1c71ea3e32d8a2eee43206":[19,4,0,8,3,1],
+"structEnetRm__IoctlPermissionTable.html#a959d5d4388d3ccb68067878eba580cd5":[19,4,0,8,3,0],
+"structEnetRm__MacAddressPool.html":[19,4,0,8,4],
+"structEnetRm__MacAddressPool.html#a07bcf0aacbdea04bef6324c9eff70109":[19,4,0,8,4,1],
+"structEnetRm__MacAddressPool.html#ad5c5b9ceccab4d022fea1a478df30689":[19,4,0,8,4,0],
+"structEnetRm__ResCfg.html":[19,4,0,8,11],
+"structEnetRm__ResCfg.html#a060249de4994fa4b50e85b9233937ca9":[19,4,0,8,11,2],
+"structEnetRm__ResCfg.html#a2ef2471c706c266c660b6739d3d50645":[19,4,0,8,11,0],
+"structEnetRm__ResCfg.html#adddefa12afa409bab36d2b975fd5288f":[19,4,0,8,11,1],
+"structEnetRm__ResCfg.html#ae54273010da9be21a4d88cc5068c6a5d":[19,4,0,8,11,3],
+"structEnetRm__ResPrms.html":[19,4,0,8,1],
+"structEnetRm__ResPrms.html#a18319e47b19a59eff8e556adf9ade3c4":[19,4,0,8,1,2],
+"structEnetRm__ResPrms.html#ab3e6e5e694a5a18f06347d502a9c3b5a":[19,4,0,8,1,1],
+"structEnetRm__ResPrms.html#aef5c0203b0c02afc893b6adfc6b754e7":[19,4,0,8,1,0],
+"structEnetRm__ResourceInfo.html":[19,4,0,8,0],
+"structEnetRm__ResourceInfo.html#a0a549dc877888817d6aee43713be5cb0":[19,4,0,8,0,4],
+"structEnetRm__ResourceInfo.html#a1018833da2e0120f2d3a00320704f507":[19,4,0,8,0,0],
+"structEnetRm__ResourceInfo.html#a94354ed8c2c70f99a9b8e89f374480af":[19,4,0,8,0,6],
+"structEnetRm__ResourceInfo.html#a9ef765ed82439a8b68b464d31f462d12":[19,4,0,8,0,5],
+"structEnetRm__ResourceInfo.html#aca13bcc9d04dbc098caaf26c85c5b62b":[19,4,0,8,0,3],
+"structEnetRm__ResourceInfo.html#adbbe5905f0481575d6175963e888ec0e":[19,4,0,8,0,1],
+"structEnetRm__ResourceInfo.html#aed6a2ca6840471e320d24dc40060e65a":[19,4,0,8,0,2],
+"structEnetTas__ConfigStatus.html":[19,4,0,10,4],
+"structEnetTas__ConfigStatus.html#a78eddac209d9894138d1da3864fe5ca5":[19,4,0,10,4,3],
+"structEnetTas__ConfigStatus.html#a85ec84f75224e9b79ada92c92cb941e6":[19,4,0,10,4,1],
+"structEnetTas__ConfigStatus.html#a982f02ae305abc26358f7efc761ea13f":[19,4,0,10,4,2],
+"structEnetTas__ConfigStatus.html#aa8429bbbe6fcf17d55eee10f8f85700c":[19,4,0,10,4,0],
+"structEnetTas__ControlList.html":[19,4,0,10,3],
+"structEnetTas__ControlList.html#a7f406efcb3b84f71ada4a61c9b3ea63f":[19,4,0,10,3,0],
+"structEnetTas__ControlList.html#ab3c74ff9df91f1c1bb2df040cfb2be62":[19,4,0,10,3,4],
+"structEnetTas__ControlList.html#ab6866461954473b6dbd7aa9db1f0a11e":[19,4,0,10,3,1],
+"structEnetTas__ControlList.html#afd4da3b610a5ee1f2cae3ab64673c471":[19,4,0,10,3,3],
+"structEnetTas__ControlList.html#afffb7eefd4adf29b44118ed1680ad1c1":[19,4,0,10,3,2],
+"structEnetTas__GateCmdEntry.html":[19,4,0,10,1],
+"structEnetTas__GateCmdEntry.html#a57f99e69caecba000ccd2f335679e5b1":[19,4,0,10,1,1],
+"structEnetTas__GateCmdEntry.html#aff1551bcc2ee532b086dff45c34aef3d":[19,4,0,10,1,0],
+"structEnetTas__GenericInArgs.html":[19,4,0,10,0],
+"structEnetTas__GenericInArgs.html#a17834e505e843f0eb74e881cd9e0a449":[19,4,0,10,0,0],
+"structEnetTas__MaxSDUTable.html":[19,4,0,10,2],
+"structEnetTas__MaxSDUTable.html#a9fd88c77a7487ecf296c978add06ac68":[19,4,0,10,2,0],
+"structEnetTas__SetAdminListInArgs.html":[19,4,0,10,5],
+"structEnetTas__SetAdminListInArgs.html#a11e5ef5ce0cc9bad4fad5cf9a91c0ae1":[19,4,0,10,5,1],
+"structEnetTas__SetAdminListInArgs.html#ac3cc8e5396da01b75d06639b43048b55":[19,4,0,10,5,0],
+"structEnetTas__SetStateInArgs.html":[19,4,0,10,6],
+"structEnetTas__SetStateInArgs.html#a077d944a8c8b30138621c8ec2607df04":[19,4,0,10,6,1],
+"structEnetTas__SetStateInArgs.html#ab316768c3c85cf4c28c189443f805f0c":[19,4,0,10,6,0],
+"structEnetTimeSync__GetEthTimestampInArgs.html":[19,4,0,11,4],
+"structEnetTimeSync__GetEthTimestampInArgs.html#a5eb987a8093cb7762d1210a5cbca7558":[19,4,0,11,4,1],
 "structEnetTimeSync__GetEthTimestampInArgs.html#a92848c0246b4b1014236ef3a8949b9c3":[19,4,0,11,4,2],
 "structEnetTimeSync__GetEthTimestampInArgs.html#aa9372a0c922633486c63ecc1c1063f97":[19,4,0,11,4,3],
 "structEnetTimeSync__GetEthTimestampInArgs.html#abe0e1ea705f2933923d5f61f6d2e727c":[19,4,0,11,4,0],
@@ -91,9 +197,10 @@ var NAVTREEINDEX60 =
 "structFirewall__Target.html#a1a130f0638cc40d060be1a5b008ef362":[19,7,33,1,1],
 "structFirewall__Target.html#a6dc08a127587462f7272ba34fcb13202":[19,7,33,1,0],
 "structFirmwareUpdateReq__t.html":[19,7,17,14],
-"structFirmwareUpdateReq__t.html#a1585c4ce4bca3e295f35a9ffd09fece9":[19,7,17,14,2],
 "structFirmwareUpdateReq__t.html#a1e35264b745dbd898621ac266168e101":[19,7,17,14,1],
 "structFirmwareUpdateReq__t.html#a463a78b6ea9280aa15131fbc264a0bc6":[19,7,17,14,0],
+"structFirmwareUpdateReq__t.html#a75b8d4e2369d40662df06e5e5bbab31e":[19,7,17,14,2],
+"structFirmwareUpdateReq__t.html#a9a8459ba4181862ec8b706e8548adfbd":[19,7,17,14,3],
 "structFlashBankCopy__t.html":[19,7,17,19],
 "structFlashBankCopy__t.html#ad1220dd6b3216f69921bff5b11ed4a74":[19,7,17,19,0],
 "structFlash__Attrs.html":[19,1,1,4],
@@ -112,6 +219,7 @@ var NAVTREEINDEX60 =
 "structFlash__Attrs.html#afbf10107b2ef425512e4cfa7125aafdb":[19,1,1,4,3],
 "structFlash__Attrs.html#aff4d7214894937b329a7a36a24fcabce":[19,1,1,4,13],
 "structFlash__Config.html":[19,1,1,5],
+"structFlash__Config.html#a1a59751bde097d04063251b1e59b4b5b":[19,1,1,5,6],
 "structFlash__Config.html#a5432fdd022fe3d125b81e44e003e9bbf":[19,1,1,5,0],
 "structFlash__Config.html#a6155ab0b6c5dfdd4e06b1b51c032eccc":[19,1,1,5,1],
 "structFlash__Config.html#abafe9fd498cad9c38defa06383183499":[19,1,1,5,5],
@@ -141,113 +249,5 @@ var NAVTREEINDEX60 =
 "structFlash__DevConfig.html#aa34b6b36b967b4d9f0d6a6f67d90296d":[19,1,1,1,19],
 "structFlash__DevConfig.html#aa7a680fe04d589f1c8191cd822b8a305":[19,1,1,1,21],
 "structFlash__DevConfig.html#ab283ed5ac28888b6d2f4ece2a2697e44":[19,1,1,1,20],
-"structFlash__DevConfig.html#ab2acdfad5f7e49651aff07b71fd31310":[19,1,1,1,10],
-"structFlash__DevConfig.html#aceece3d92326136df48c08aad0b56109":[19,1,1,1,2],
-"structFlash__DevConfig.html#aec4d61cd7bbcd19ee93805ec6ebd4203":[19,1,1,1,28],
-"structFlash__DevConfig.html#aeea07d11c4e7bdafaeb17d5d07f56ea6":[19,1,1,1,4],
-"structFlash__DevConfig.html#af26d4f2cc7406d7d47b233d74813c859":[19,1,1,1,24],
-"structFlash__DevConfig.html#af9aaea904629353d937dc22dc5837b94":[19,1,1,1,0],
-"structFlash__DevConfig.html#afab0fc477109d917238beffbee9712a0":[19,1,1,1,16],
-"structFlash__DevConfig.html#afb423a4bf94438d4e449227ca0c2596c":[19,1,1,1,17],
-"structFlash__DevConfig.html#afe362f0bdd2a40fc03d2089e45daa312":[19,1,1,1,5],
-"structFlash__Fxns.html":[19,1,1,3],
-"structFlash__Fxns.html#a10e797df598663ad56a0de7fc97948e6":[19,1,1,3,6],
-"structFlash__Fxns.html#a188c641aa936112bf55838b157b6c75a":[19,1,1,3,5],
-"structFlash__Fxns.html#a1ea1056103cb90dffb102efc9851fa9b":[19,1,1,3,2],
-"structFlash__Fxns.html#a2a2e6bba1dc3f3b11b62e551075a87f8":[19,1,1,3,8],
-"structFlash__Fxns.html#a33282037c2d497a3eac09fa35d9cf101":[19,1,1,3,0],
-"structFlash__Fxns.html#a6254564547e4ab2f04437ad5f6e03e06":[19,1,1,3,7],
-"structFlash__Fxns.html#a70868dc6e7f457f10ffa666ede4aea15":[19,1,1,3,4],
-"structFlash__Fxns.html#aa1415bbaf626f2f0e423a3aed1385df7":[19,1,1,3,1],
-"structFlash__Fxns.html#af08a758ebcd6e677c3c1e295ce864f69":[19,1,1,3,3],
-"structFlash__NandConfig.html":[19,1,1,0],
-"structFlash__NandConfig.html#a08f46b686caee1090d0a7a2d6a2b5174":[19,1,1,0,0],
-"structFlash__NandConfig.html#a1f2a71b95ea2120bdfa3ffa31529df63":[19,1,1,0,1],
-"structFlash__NandConfig.html#a303a8c58aaac6b17b891e6e675ab0f6d":[19,1,1,0,12],
-"structFlash__NandConfig.html#a41cf4d4568b4b04f11d180b297d6673c":[19,1,1,0,6],
-"structFlash__NandConfig.html#a5bf41e1e7181d922bb7f31ff24dec4e6":[19,1,1,0,3],
-"structFlash__NandConfig.html#a5e22b8ea43397f302a338df558f40487":[19,1,1,0,10],
-"structFlash__NandConfig.html#a7379c773feff9d3d9ffc369ef9c9717d":[19,1,1,0,4],
-"structFlash__NandConfig.html#a782a6418f669bcb4261513e37c47b916":[19,1,1,0,8],
-"structFlash__NandConfig.html#ab04ae84b55ce949a3682c430b5ec0e33":[19,1,1,0,7],
-"structFlash__NandConfig.html#ac26788435610e8982ae141039c374b91":[19,1,1,0,2],
-"structFlash__NandConfig.html#ae26fb17dbf1b97522965b1d4b67e7642":[19,1,1,0,9],
-"structFlash__NandConfig.html#af151e797eaf119f15c9ecce04aebe7fa":[19,1,1,0,11],
-"structFlash__NandConfig.html#af65ff3790948df048400a56d9684c83d":[19,1,1,0,5],
-"structFlash__Params.html":[19,1,1,2],
-"structFlash__Params.html#adbf8c9b96aeeeca61ee090ea1d0fe554":[19,1,1,2,1],
-"structFlash__Params.html#af84f256d7f327843ed0ea6abdd7a59c8":[19,1,1,2,0],
-"structGPMC__AddrRegion.html":[19,7,16,3],
-"structGPMC__AddrRegion.html#a81c14c90e58a2d8d26f49b509d960e8c":[19,7,16,3,1],
-"structGPMC__AddrRegion.html#a9579b8114d54e636427cb2ba1b1867f1":[19,7,16,3,0],
-"structGPMC__Config.html":[19,7,16,7],
-"structGPMC__Config.html#a2f011c3a9c7936c508ba2d731231bc91":[19,7,16,7,0],
-"structGPMC__Config.html#aaf1a4cc0a3debf6d1044f197bef86171":[19,7,16,7,1],
-"structGPMC__HwAttrs.html":[19,7,16,6],
-"structGPMC__HwAttrs.html#a1f7fd5933bb6f1755615d3c919c5bebb":[19,7,16,6,17],
-"structGPMC__HwAttrs.html#a2f8a8fcf2b68520dfbd35461a4b39c70":[19,7,16,6,4],
-"structGPMC__HwAttrs.html#a326510add02f7eb030df17fd4c17fea3":[19,7,16,6,2],
-"structGPMC__HwAttrs.html#a4445c4e5fcf3df4c5e2fc20e289b3054":[19,7,16,6,18],
-"structGPMC__HwAttrs.html#a596002e87df70aa3ebd980ba4032fe35":[19,7,16,6,14],
-"structGPMC__HwAttrs.html#a6f82978a52e84ba0f9dfa196eaea9dd8":[19,7,16,6,19],
-"structGPMC__HwAttrs.html#a75fa7f62ed38bfff07758add5255bdf2":[19,7,16,6,13],
-"structGPMC__HwAttrs.html#a7fb48eddaf8e89228178611d36e64020":[19,7,16,6,11],
-"structGPMC__HwAttrs.html#a81c95feba14b93a7cca8aeb7d685dd3e":[19,7,16,6,20],
-"structGPMC__HwAttrs.html#a8aa3cdbee377ee4c76f4f413d32a47cf":[19,7,16,6,9],
-"structGPMC__HwAttrs.html#a8c2320056a2986303f8d230aa9dbdf14":[19,7,16,6,21],
-"structGPMC__HwAttrs.html#a922e5f8bb55e751f2478d72e1a912386":[19,7,16,6,8],
-"structGPMC__HwAttrs.html#a92fd2f9baf0d0e87cfe8e0fd08500077":[19,7,16,6,10],
-"structGPMC__HwAttrs.html#a989ed426a43aa8233358340f69a4371e":[19,7,16,6,3],
-"structGPMC__HwAttrs.html#aaba1184bdb03b96e231da1034e0e6b87":[19,7,16,6,7],
-"structGPMC__HwAttrs.html#aca281638e778d8cda184db5d44e2074f":[19,7,16,6,15],
-"structGPMC__HwAttrs.html#acd3337795dc34672f10149f4d6ba2e07":[19,7,16,6,1],
-"structGPMC__HwAttrs.html#ad7ab96009c29ec8f49b55d6707278c36":[19,7,16,6,16],
-"structGPMC__HwAttrs.html#ae22c3c5ec843b9bbfac0f67c53d8437a":[19,7,16,6,0],
-"structGPMC__HwAttrs.html#ae25e9320a8df4011bcd84baa6d0b1c53":[19,7,16,6,6],
-"structGPMC__HwAttrs.html#ae722cea92e148aaf135a9bedd15053dd":[19,7,16,6,12],
-"structGPMC__HwAttrs.html#afa7a1d76f13bc6c18ee6f988057e4c6a":[19,7,16,6,5],
-"structGPMC__Object.html":[19,7,16,4],
-"structGPMC__Object.html#a11a051e0fad042034419169f032ee06c":[19,7,16,4,7],
-"structGPMC__Object.html#a4813bf46af45f70399153e5844b692bf":[19,7,16,4,1],
-"structGPMC__Object.html#a5e4976f474768f1232a7e1f238130bfe":[19,7,16,4,3],
-"structGPMC__Object.html#a7ed302507db21ce75f485e2780976c8e":[19,7,16,4,6],
-"structGPMC__Object.html#a85e6593fce3ff02231922361cb0507c7":[19,7,16,4,4],
-"structGPMC__Object.html#aa7aeeb8473721be27a0d01a40cd94f23":[19,7,16,4,5],
-"structGPMC__Object.html#ab2fcf746b3547cab94dc3fca4af7e79d":[19,7,16,4,2],
-"structGPMC__Object.html#ac452236206e7d5fae186364047743eaf":[19,7,16,4,0],
-"structGPMC__Params.html":[19,7,16,2],
-"structGPMC__Params.html#a00fc03d6f98d35ae592cb68239eac201":[19,7,16,2,1],
-"structGPMC__Params.html#a6526fe9ca831c12d164b0dccb2f96fa6":[19,7,16,2,2],
-"structGPMC__Params.html#a8a30b78168c396c93757306fa095a42f":[19,7,16,2,6],
-"structGPMC__Params.html#a945c6b9a642cfaeef001109658f69b5d":[19,7,16,2,0],
-"structGPMC__Params.html#ac792f6084541cbf7ee49a02c617194ee":[19,7,16,2,3],
-"structGPMC__Params.html#adfa04cafc7fc170cd256b96bb889d2e5":[19,7,16,2,5],
-"structGPMC__Params.html#aef9f9852760141deb7d6b9dfe64811d6":[19,7,16,2,7],
-"structGPMC__Params.html#afd324e2a4f0210e1fb9c576ff427c397":[19,7,16,2,4],
-"structGPMC__Transaction.html":[19,7,16,1],
-"structGPMC__Transaction.html#a0061ab8f2eb54cf7bf571c2fd0ceecf8":[19,7,16,1,5],
-"structGPMC__Transaction.html#a10472ac79732b247602bde9902e2ec89":[19,7,16,1,2],
-"structGPMC__Transaction.html#a32de689d3c4dd74723efc0ac3ebed4a4":[19,7,16,1,1],
-"structGPMC__Transaction.html#a4d736b25251d45368c3c309ee7a1026d":[19,7,16,1,3],
-"structGPMC__Transaction.html#a95e785470758a7095a2e0caaa027cff3":[19,7,16,1,4],
-"structGPMC__Transaction.html#ad59eebdc4e2fa7bb7e64e5274f8981cf":[19,7,16,1,0],
-"structGPMC__nandCmdParams.html":[19,7,16,0],
-"structGPMC__nandCmdParams.html#a0a7d4b8144e3eadafb25a9b4a6f56f44":[19,7,16,0,2],
-"structGPMC__nandCmdParams.html#a13b359958cf5f1574b2e7a667d7651cb":[19,7,16,0,6],
-"structGPMC__nandCmdParams.html#a6b6e5d9016168791b2f0565b7eb16efe":[19,7,16,0,0],
-"structGPMC__nandCmdParams.html#a75f69ddba73e1b0cc0532a0e63304fe5":[19,7,16,0,7],
-"structGPMC__nandCmdParams.html#a906a364788df4a7e04660c4409b15b9a":[19,7,16,0,4],
-"structGPMC__nandCmdParams.html#aac3b39beec91910c0af0633f59db0c1a":[19,7,16,0,3],
-"structGPMC__nandCmdParams.html#aaebfd745e76a8b1e048285e06a82c3e0":[19,7,16,0,5],
-"structGPMC__nandCmdParams.html#aeaec3a57393e3c11e2a45b8f1e2a28f2":[19,7,16,0,1],
-"structGPMC__timingParams.html":[19,7,16,5],
-"structGPMC__timingParams.html#a058f089b4d1abbb1de31bc12574c9b5d":[19,7,16,5,5],
-"structGPMC__timingParams.html#a2985a55fd1e0ac44301ecf60a6e656e4":[19,7,16,5,16],
-"structGPMC__timingParams.html#a3da646bdeb37a097023906eefafd62c0":[19,7,16,5,0],
-"structGPMC__timingParams.html#a571cb173a71519a1508ec272ba1c2d97":[19,7,16,5,17],
-"structGPMC__timingParams.html#a6be3cec0c11f26f8d81d763af29e2a96":[19,7,16,5,10],
-"structGPMC__timingParams.html#a6c965c6a1648252120335ecff51664b0":[19,7,16,5,6],
-"structGPMC__timingParams.html#a6d1f8bc55841d78e48ea2d7c26a1c5ee":[19,7,16,5,2],
-"structGPMC__timingParams.html#a728eb51adc2c0642ebeb969a0bf2bbdb":[19,7,16,5,20],
-"structGPMC__timingParams.html#a7caf580937934428c660d175125953cb":[19,7,16,5,3]
+"structFlash__DevConfig.html#ab2acdfad5f7e49651aff07b71fd31310":[19,1,1,1,10]
 };
